@@ -24,6 +24,9 @@ class GameWidget : public QWidget
     // bringt level auf neuesten stand
     void updateLevel (int);
 
+    // restart current level
+    void restartLevel();
+
     // getbutton erhlt button der gedrckt wurde
     void getButton (int);
 
