@@ -18,7 +18,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-  $Id: kbgfibschat.cpp,v 1.17 2002/02/28 07:32:14 hoefkens Exp $
+  $Id: kbgfibschat.cpp,v 1.19 2002/07/23 10:27:22 binner Exp $
 
 */
 
@@ -232,18 +232,18 @@ KBgChat::KBgChat(QWidget *parent, const char *name)
     /*
      * Define set of available actions
      */
-    d->mAct[KBgChatPrivate::Inquire] = new KAction(i18n("Info on"),
+    d->mAct[KBgChatPrivate::Inquire] = new KAction(i18n("Info On"),
                                                    QIconSet(kapp->iconLoader()->loadIcon(
                                                                 "help.xpm", KIcon::Small)),
                                                    0, this, SLOT(slotInquire()), actions);
-    d->mAct[KBgChatPrivate::Talk]    = new KAction(i18n("Talk to"),
+    d->mAct[KBgChatPrivate::Talk]    = new KAction(i18n("Talk To"),
                                                    QIconSet(kapp->iconLoader()->loadIcon(
                                                                 PROG_NAME "-chat.png", KIcon::Small)),
                                                    0, this, SLOT(slotTalk()), actions);
 
     d->mAct[KBgChatPrivate::InviteD]  = new KAction(i18n("Use Dialog"),    0, this,
                                                     SLOT(slotInviteD()),  actions);
-    d->mAct[KBgChatPrivate::Invite1]  = new KAction(i18n("1 Point match"), 0, this,
+    d->mAct[KBgChatPrivate::Invite1]  = new KAction(i18n("1 Point Match"), 0, this,
                                                     SLOT(slotInvite1()),  actions);
     d->mAct[KBgChatPrivate::Invite2]  = new KAction(i18n("2 Point Match"), 0, this,
                                                     SLOT(slotInvite2()),  actions);
@@ -367,7 +367,7 @@ void KBgChat::getSetupPages(KTabCtl *nb, int space)
 
     QWhatsThis::add(w, i18n("Select all the users you want "
                             "to remove from the gag list "
-                            "and then click Ok. Afterwards "
+                            "and then click OK. Afterwards "
                             "you will again hear what they shout."));
 
     gl->addWidget(d->mLb, 0, 0);
