@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-  $Id: kplayerlist.cpp,v 1.13 2002/02/28 07:32:14 hoefkens Exp $
+  $Id: kplayerlist.cpp,v 1.16.2.1 2002/12/06 12:23:21 lunakl Exp $
 
 */
 
@@ -286,20 +286,20 @@ KFibsPlayerList::KFibsPlayerList(QWidget *parent, const char *name)
     /*
      * Create the whole set of actions
      */
-    d->mAct[KFibsPlayerListPrivate::Info] = new KAction(i18n("Info   "),
+    d->mAct[KFibsPlayerListPrivate::Info] = new KAction(i18n("Info"),
                                                         QIconSet(kapp->iconLoader()->loadIcon
                                                                  ("help.xpm", KIcon::Small)),
                                                         0, this, SLOT(slotInfo()),   actions);
-    d->mAct[KFibsPlayerListPrivate::Talk] = new KAction(i18n("Talk   "),
+    d->mAct[KFibsPlayerListPrivate::Talk] = new KAction(i18n("Talk"),
                                                         QIconSet(kapp->iconLoader()->loadIcon
                                                                  (PROG_NAME "-chat.png", KIcon::Small)),
                                                         0, this, SLOT(slotTalk()),   actions);
 
-    d->mAct[KFibsPlayerListPrivate::Look]     = new KAction(i18n("Look   "), 0, this, SLOT(slotLook()),   actions);
-    d->mAct[KFibsPlayerListPrivate::Watch]    = new KAction(i18n("Watch  "), 0, this, SLOT(slotWatch()),  actions);
+    d->mAct[KFibsPlayerListPrivate::Look]     = new KAction(i18n("Look"), 0, this, SLOT(slotLook()),   actions);
+    d->mAct[KFibsPlayerListPrivate::Watch]    = new KAction(i18n("Watch"), 0, this, SLOT(slotWatch()),  actions);
     d->mAct[KFibsPlayerListPrivate::Unwatch]  = new KAction(i18n("Unwatch"), 0, this, SLOT(slotUnwatch()),actions);
-    d->mAct[KFibsPlayerListPrivate::BlindAct] = new KAction(i18n("Blind  "), 0, this, SLOT(slotBlind()),  actions);
-    d->mAct[KFibsPlayerListPrivate::Update]   = new KAction(i18n("Update "), 0, this, SLOT(slotUpdate()), actions);
+    d->mAct[KFibsPlayerListPrivate::BlindAct] = new KAction(i18n("Blind"), 0, this, SLOT(slotBlind()),  actions);
+    d->mAct[KFibsPlayerListPrivate::Update]   = new KAction(i18n("Update"), 0, this, SLOT(slotUpdate()), actions);
 
     d->mAct[KFibsPlayerListPrivate::Reload] = KStdAction::redisplay(this, SLOT(slotReload()), actions);
     d->mAct[KFibsPlayerListPrivate::Mail]   = KStdAction::mail(this, SLOT(slotMail()),   actions);
@@ -307,7 +307,7 @@ KFibsPlayerList::KFibsPlayerList(QWidget *parent, const char *name)
 
     d->mAct[KFibsPlayerListPrivate::InviteD]  = new KAction(i18n("Use Dialog"),    0, this,
                                                             SLOT(slotInviteD()), actions);
-    d->mAct[KFibsPlayerListPrivate::Invite1]  = new KAction(i18n("1 Point match"), 0, this,
+    d->mAct[KFibsPlayerListPrivate::Invite1]  = new KAction(i18n("1 Point Match"), 0, this,
                                                             SLOT(slotInvite1()), actions);
     d->mAct[KFibsPlayerListPrivate::Invite2]  = new KAction(i18n("2 Point Match"), 0, this,
                                                             SLOT(slotInvite2()), actions);
@@ -451,7 +451,7 @@ void KFibsPlayerList::getSetupPages(KTabCtl *nb, int space)
      * Label
      */
     QGroupBox *gbl = new QGroupBox(w);
-    gbl->setTitle(i18n("Column Selection:"));
+    gbl->setTitle(i18n("Column Selection"));
 
     gl->addWidget(gbl, 0, 0);
 
@@ -724,7 +724,7 @@ void KFibsPlayerList::changePlayer(const QString &line)
     entry[Status][0] = '\0';
 
     // the line comes from FIBS and is 7 bit ASCII
-    sscanf(line.latin1(), "%s %s %s %s %s %s %s %s %s %s %s %s", entry[Player], entry[Opponent],
+    sscanf(line.latin1(), "%99s %99s %99s %1s %1s %99s %99s %99s %99s %99s %99s %99s", entry[Player], entry[Opponent],
            entry[Watches], ready, away, entry[Rating], entry[Experience], entry[Idle], entry[Time],
            entry[Host], entry[Client], entry[Email]);
 
