@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-  $Id: kbgoffline.cpp,v 1.9 2001/10/26 22:45:52 hoefkens Exp $
+  $Id: kbgoffline.cpp,v 1.11 2002/07/07 08:40:22 binner Exp $
 
 */
 
@@ -196,7 +196,7 @@ void KBgEngineOffline::getSetupPages(KDialogBase *nb)
     /*
      * Group boxes
      */
-    QGroupBox *gbn = new QGroupBox(i18n("Names:"), w);
+    QGroupBox *gbn = new QGroupBox(i18n("Names"), w);
 
     gl->addWidget(gbn, 0, 0);
 
@@ -206,8 +206,8 @@ void KBgEngineOffline::getSetupPages(KDialogBase *nb)
     d->mLe[1] = new QLineEdit(d->mName[1], gbn);
 
     QLabel *lb[2];
-    lb[0] = new QLabel(i18n("First player"), gbn);
-    lb[1] = new QLabel(i18n("Second player"), gbn);
+    lb[0] = new QLabel(i18n("First player:"), gbn);
+    lb[1] = new QLabel(i18n("Second player:"), gbn);
 
     for (int i = 0; i < 2; i++) {
         gl->addWidget(lb[i], i, 0);
@@ -285,8 +285,8 @@ void KBgEngineOffline::newGame()
     if (d->mGameFlag && (KMessageBox::warningYesNo((QWidget *)parent(),
                                                    i18n("A game is currently in progress. "
                                                         "Starting a new one will terminate it."),
-                                                   QString::null, i18n("Start new game"),
-                                                   i18n("Continue old game"))
+                                                   QString::null, i18n("Start New Game"),
+                                                   i18n("Continue Old Game"))
                          == KMessageBox::No))
         return;
 
@@ -389,11 +389,11 @@ bool KBgEngineOffline::queryPlayerName(int w)
     if (w == US) {
         name = &d->mName[0];
         text = i18n("Please enter the nickname of the player whose home\n"
-                    "is in the lower half of the board.");
+                    "is in the lower half of the board:");
     } else {
         name = &d->mName[1];
         text = i18n("Please enter the nickname of the player whose home\n"
-                    "is in the upper half of the board.");
+                    "is in the upper half of the board:");
     }
 
     do {
