@@ -22,6 +22,12 @@
 /*
 
   $Log: kbgboard.cpp,v $
+  Revision 1.18.2.1  2002/12/09 23:27:22  faure
+  Backport all the bugfixes from HEAD
+
+  Revision 1.18  2002/04/25 11:01:59  binner
+  CVS_SILENT Style guide fixes.
+
   Revision 1.17  2001/11/02 10:25:07  mlaurent
   Fix includes
 
@@ -187,9 +193,9 @@ void KBgBoardSetup::getSetupPages(KDialogBase *nb)
 	QButtonGroup *gm = new QButtonGroup(w);
 	QGroupBox    *go = new QGroupBox(w);
 
-	ga->setTitle(i18n("Colors:"));
-	gm->setTitle(i18n("Short Moves:"));
-	go->setTitle(i18n("Options:"));
+	ga->setTitle(i18n("Colors"));
+	gm->setTitle(i18n("Short Moves"));
+	go->setTitle(i18n("Options"));
 
 	gl->addWidget(ga, 0, 0);
 	gl->addWidget(gm, 1, 0);
@@ -1690,6 +1696,8 @@ KBgBoardHome::KBgBoardHome(QWidget * parent, int numID)
 				   "the dice will roll them. Moreover, the cube might be placed "
 				   "on the home bar and if it can be doubled, double clicking it "
 				   "will do so."));
+	savedDice[0] = -1;
+	savedDice[1] = -1;
 }
 
 /*
