@@ -29,6 +29,7 @@
 #include <kfiledialog.h>
 #include <kscoredialog.h>
 #include <kstatusbar.h>
+#include <kkeydialog.h>
 
 #include "kbounce.h"
 #include "game.h"
@@ -98,8 +99,11 @@ KJezzball::KJezzball()
 
     // create demo game
     createLevel( 1 );
-    statusBar()->message( i18n("Press <Space> to start a game!") );
+    statusBar()->message( i18n("Press %1 to start a game!").arg(actionCollection()->action("game_new")->shortcut().seq(0).toString()) );
     //m_gameWidget->display( i18n("Press <Space> to start a game!") );
+
+    setFocusPolicy(QWidget::StrongFocus);
+    setFocus();
 }
 
 /**
@@ -107,7 +111,14 @@ KJezzball::KJezzball()
  */
 void KJezzball::initXMLUI()
 {
-    KStdGameAction::gameNew( this, SLOT(newGame()), actionCollection() );
+    KAction* gameNew = KStdGameAction::gameNew( this, SLOT(newGame()), actionCollection() );
+
+    // AB: originally KBounce/KJezzball used Space for new game - but Ctrl+N is
+    // default. We solve this by providing space as an alternative key
+    KShortcut s = gameNew->shortcut();
+    s.append(QKeySequence(Key_Space));
+    gameNew->setShortcut(s);
+    
     KStdGameAction::quit( this, SLOT(close()), actionCollection() );
     KStdGameAction::highscores(this, SLOT(showHighscore()), actionCollection() );
     KStdGameAction::pause(this, SLOT(pauseGame()), actionCollection());
@@ -119,6 +130,7 @@ void KJezzball::initXMLUI()
 
     show->setEnabled( !m_backgroundDir.isEmpty() );
     show->setChecked( m_showBackground );
+    KStdAction::keyBindings(this, SLOT(keyBindings()), actionCollection());
 
     createGUI( "kbounceui.rc" );
 }
@@ -150,6 +162,9 @@ void KJezzball::closeGame()
 {
     if ( m_state!=Idle )
     {
+        int old_state = m_state;
+        if (old_state == Running)
+            pauseGame();
         int ret = KMessageBox::questionYesNo( this, i18n("Do you really want to close the running game?") );
         if ( ret==KMessageBox::Yes )
         {
@@ -157,6 +172,10 @@ void KJezzball::closeGame()
             m_state = Idle;
             highscore();
         }
+        else if (old_state == Running)
+        {
+            pauseGame(); // Unpause
+        }
     }
 }
 
@@ -279,9 +298,17 @@ QPixmap KJezzball::getBackgroundPixmap()
         return QPixmap();
     }
 
-    // return random pixmap
-    int num = rand() % dir.count();
-    return QPixmap( dir.absFilePath( dir[num] ) );
+    if (dir.count() > 1)
+    {
+        // return random pixmap
+        int num = rand() % dir.count();
+        return QPixmap( dir.absFilePath( dir[num] ) );
+    }
+    else if (dir.count()==1)
+    {
+    	return QPixmap( dir.absFilePath(dir[0]) );
+    }
+    else return QPixmap();
 }
 
 void KJezzball::focusOutEvent( QFocusEvent *ev )
@@ -310,18 +337,6 @@ void KJezzball::focusInEvent ( QFocusEvent *ev )
     KMainWindow::focusInEvent( ev );
 }
 
-void KJezzball::keyPressEvent( QKeyEvent *ev )
-{
-   if ((m_state==Idle) && (ev->key() == Key_Space))
-   {
-      ev->accept();
-      newGame();
-      return;
-   }
-   KMainWindow::keyPressEvent( ev );
-}
-
-
 void KJezzball::second()
 {
     m_level.time--;
@@ -422,7 +437,7 @@ i18n("You have successfully cleared more than 75% of the board.\n") +
 i18n("%1 points: 15 points per remaining life\n").arg(m_level.lifes*15) +
 i18n("%1 points: Bonus\n").arg((m_gameWidget->percent()-75)*2*(m_game.level+5)) +
 i18n("%1 points: Total score for this level\n").arg(score) +
-i18n("On to level %1, remember you get %2 lives this time!")).arg(m_game.level+1).arg(m_game.level+2);
+i18n("On to level %1. Remember you get %2 lives this time!")).arg(m_game.level+1).arg(m_game.level+2);
 
    KMessageBox::information( this,foo );
 
@@ -453,4 +468,9 @@ void KJezzball::highscore()
     d.exec();
 }
 
+void KJezzball::keyBindings()
+{
+    KKeyDialog::configure(actionCollection(), this);
+}
+
 #include "kbounce.moc"
