@@ -4,7 +4,6 @@
 #include <qtimer.h>
 #include <qclipboard.h>
 
-#include <kaccel.h>
 #include <kaction.h>
 #include <kapplication.h>
 #include <kconfig.h>
@@ -265,7 +264,7 @@ void AbTop::toggleStatusbar()
 void AbTop::configure()
 {
   KDialogBase *dlg = new KDialogBase( 0, "ConfigureEvaluation", true,
-				      i18n("Configure Evaluation..."),
+				      i18n("Configure Evaluation"),
 				      KDialogBase::Ok | KDialogBase::Cancel, 
 				      KDialogBase::Ok, true);
 
@@ -565,7 +564,7 @@ void AbTop::setupStatusBar()
   KStatusBar* status = statusBar();
 
   QString t = i18n("Press %1 for a new game")
-    .arg( KStdAccel::shortcut(KStdAccel::New).toString() );
+    .arg( actionCollection()->action("game_new")->shortcut().seq(0).toString());
   statusLabel = new QLabel( t, status, "statusLabel" );
   status->addWidget(statusLabel,1,false);
 
@@ -669,7 +668,7 @@ void AbTop::updateStatus()
   }
   else if (timerState == noGame) {
     tmp = i18n("Press %1 for a new game")
-      .arg( KStdAccel::shortcut(KStdAccel::New).toString() );
+      .arg( actionCollection()->action("game_new")->shortcut().toString());
   }
   else {
     if (timerState == gameOver) {
