@@ -29,7 +29,6 @@
 #include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kaccel.h>
 #include <kkeydialog.h>
 #include <kiconloader.h>
 #include <kcolordialog.h>
@@ -69,10 +68,11 @@ KJumpingCube::KJumpingCube()
 
    QString s;
    // init statusbar
-   s = i18n("on turn: Player %1").arg(1);
+   s = i18n("On turn: Player %1").arg(1);
    statusBar()->insertItem(s+i18n("(Computer)"),ID_STATUS_TURN,2);
    statusBar()->changeItem(s,ID_STATUS_TURN);
    statusBar()->setItemAlignment (ID_STATUS_TURN,AlignLeft | AlignVCenter);
+   statusBar()->setFixedHeight( statusBar()->sizeHint().height());
 
 
    KConfig *config=kapp->config();
@@ -324,7 +324,7 @@ void KJumpingCube::saveGame(bool saveAs)
          if(KIO::NetAccess::exists(url))
          {
             QString mes=i18n("The file %1 exists.\n"
-			     "Do you want to override it?").arg(url.url());
+			     "Do you want to overwrite it?").arg(url.url());
 	    result = KMessageBox::warningYesNoCancel(this, mes);
             if(result==KMessageBox::Cancel)
                return;
@@ -373,7 +373,7 @@ void KJumpingCube::openGame()
 
       if(!KIO::NetAccess::exists(url.url()))
       {
-         QString mes=i18n("The file %1 doesn't exists!").arg(url.url());
+         QString mes=i18n("The file %1 does not exist!").arg(url.url());
          KMessageBox::sorry(this,mes);
 
          fileOk=false;
@@ -453,7 +453,7 @@ void KJumpingCube::changeColor(int player)
 
 void KJumpingCube::changePlayer(int newPlayer)
 {
-   QString s=i18n("on turn: Player %1");
+   QString s=i18n("On turn: Player %1");
    s=s.arg(newPlayer);
    if(view->isComputer((KCubeBoxWidget::Player)newPlayer))
       s+=i18n("(Computer)");
@@ -535,7 +535,7 @@ void KJumpingCube::skillChange()
       skillStr=i18n("Expert");
       break;
  }
- QString s=i18n("Skill of computerplayer is now: %1").arg(skillStr);
+ QString s=i18n("The computer player's skill level is now: %1").arg(skillStr);
  statusBar()->message(s,MESSAGE_TIME);
 }
 
