@@ -17,7 +17,7 @@
 #ifndef __CFG_H
 #define __CFG_H 1
 
-#define LINESVERSION "1.0"
+#define LINESVERSION "1.1"
 
 #define NCOLORS 7
 #define BALLSDROP 3
@@ -30,6 +30,8 @@
 #define STEPTIME 3
 #define NORMALBALL PIXTIME + BOOMBALLS
 #define TIMERCLOCK 25
+#define DEMO_LEVEL -100
+#define DEMO_SEQUENCE 42
 
 enum Anim
 {
