@@ -432,7 +432,7 @@ GameBoard::scanForSurvivors( void )
             msg = i18n("The once mighty empire of %1 has fallen in ruins.")
                   .arg(plr->getName());
             KMessageBox::information( this, msg,
-				      i18n("An Empire has fallen...") );
+				      i18n("An Empire Has Fallen") );
         }
     }
 
@@ -444,7 +444,7 @@ GameBoard::scanForSurvivors( void )
             msg = i18n("The fallen empire of %1 has staggered back to life.")
 		  .arg(plr->getName());
 	    KMessageBox::information( this, msg,
-				      i18n("Up from the ashes...") );
+				      i18n("Up From the Ashes") );
         }
     }
 }
@@ -780,9 +780,7 @@ GameBoard::measureDistance()
 void
 GameBoard::showScores()
 {
-
-    ScoreDlg *scoreDlg = new ScoreDlg( this, "Current Standings", &players );
+    ScoreDlg *scoreDlg = new ScoreDlg( this, i18n("Current Standings"), &players );
     scoreDlg->show();
-
 }
 
