@@ -1,12 +1,11 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <qslider.h>
 
 #include "gameenddlg.h"
-#include <klocale.h>
 #include "gameenddlg.moc"
 
 GameEndDlg::GameEndDlg( QWidget *parent )
