@@ -23,13 +23,11 @@
 MainWindow::MainWindow( const char *name) : KMainWindow( 0, name )
 {
 
-    setCaption( i18n("GNU-Lactic Conquest") );
+    setCaption( i18n("Galactic Conquest") );
 
     setupGameBoard();
     setupKAction();
 
-    resize( 600,550 );
-    setFixedSize( 600, 550 );
     show();
 }
 
