@@ -2,6 +2,7 @@
 #include <kstaticdeleter.h>
 #include <qpainter.h>
 #include <kdebug.h>
+#include <deck.h>
 #include <assert.h>
 #include "pile.h"
 #include "kmainwindow.h"
@@ -28,10 +29,12 @@ void DealerInfoList::add(DealerInfo *dealer)
     list.append(dealer);
 }
 
+Dealer *Dealer::s_instance = 0;
+
 Dealer::Dealer( KMainWindow* _parent , const char* _name )
     : QCanvasView( 0, _parent, _name ), towait(0), myActions(0),
 ademo(0), ahint(0), aredeal(0),
-takeTargets(false), _won(false), _waiting(0), stop_demo_next(false)
+      takeTargets(false), _won(false), _waiting(0), stop_demo_next(false), _autodrop(true)
 {
     setResizePolicy(QScrollView::Manual);
     setVScrollBarMode(AlwaysOff);
@@ -44,14 +47,23 @@ takeTargets(false), _won(false), _waiting(0), stop_demo_next(false)
     undoList.setAutoDelete(true);
     demotimer = new QTimer(this);
     connect(demotimer, SIGNAL(timeout()), SLOT(demo()));
+    assert(!s_instance);
+    s_instance = this;
+}
+
+const Dealer *Dealer::instance()
+{
+    return s_instance;
 }
 
 void Dealer::setBackgroundPixmap(const QPixmap &background, const QColor &midcolor)
 {
     _midcolor = midcolor;
     canvas()->setBackgroundPixmap(background);
-    for (PileList::Iterator it = piles.begin(); it != piles.end(); ++it)
+    for (PileList::Iterator it = piles.begin(); it != piles.end(); ++it) {
         (*it)->resetCache();
+        (*it)->initSizes();
+    }
 }
 
 void Dealer::setupActions() {
@@ -95,6 +107,9 @@ Dealer::~Dealer()
 
     while (!piles.isEmpty())
         delete piles.first(); // removes itself
+
+    if (s_instance == this)
+        s_instance = 0;
 }
 
 KMainWindow *Dealer::parent() const
@@ -185,6 +200,11 @@ void Dealer::newHint(MoveHint *mh)
     hints.append(mh);
 }
 
+bool Dealer::isMoving(Card *c) const
+{
+    return movingCards.find(c) != movingCards.end();
+}
+
 void Dealer::contentsMouseMoveEvent(QMouseEvent* e)
 {
     if (movingCards.isEmpty())
@@ -279,21 +299,28 @@ void Dealer::contentsMousePressEvent(QMouseEvent* e)
         if (list.first()->rtti() == Card::RTTI) {
             Card *c = dynamic_cast<Card*>(list.first());
             assert(c);
-            movingCards = c->source()->cardPressed(c);
+            CardList mycards = c->source()->cardPressed(c);
+            for (CardList::Iterator it = mycards.begin(); it != mycards.end(); ++it)
+                (*it)->setAnimated(false);
+            movingCards = mycards;
             moving_start = e->pos();
-            return;
         }
+        return;
     }
 
     if (e->button() == RightButton) {
         if (list.first()->rtti() == Card::RTTI) {
             Card *preview = dynamic_cast<Card*>(list.first());
             assert(preview);
-            preview->getUp();
+            if (!preview->animated() && !isMoving(preview))
+                preview->getUp();
         }
+        return;
     }
 
-    movingCards.clear();
+    // if it's nothing else, we move the cards back
+    contentsMouseReleaseEvent(e);
+
 }
 
 class Hit {
@@ -494,23 +521,21 @@ void Dealer::resizeEvent(QResizeEvent *e)
         QCanvasView::resizeEvent(e);
 }
 
-void Dealer::cardClicked(Card *c) {
-    kdDebug(11111) << "card clicked " << c->name() << endl;
-    c->source()->cardClicked(c);
+bool Dealer::cardClicked(Card *c) {
+    return c->source()->cardClicked(c);
 }
 
 void Dealer::pileClicked(Pile *c) {
     c->cardClicked(0);
 }
 
-void Dealer::cardDblClicked(Card *c)
+bool Dealer::cardDblClicked(Card *c)
 {
-    c->source()->cardDblClicked(c);
-
-    kdDebug(11111) << "card dbl clicked " << c->name() << endl;
+    if (c->source()->cardDblClicked(c))
+        return true;
 
     if (c->animated())
-        return;
+        return false;
 
     if (c == c->source()->top() && c->realFace()) {
         Pile *tgt = findTarget(c);
@@ -519,8 +544,10 @@ void Dealer::cardDblClicked(Card *c)
             empty.append(c);
             c->source()->moveCards(empty, tgt);
             canvas()->update();
+            return true;
         }
     }
+    return false;
 }
 
 void Dealer::startNew()
@@ -597,7 +624,7 @@ public:
     double z;
     bool faceup;
     bool tookdown;
-    int i;
+    int source_index;
     CardState() {}
 public:
     // as every card is only once we can sort after the card.
@@ -608,10 +635,20 @@ public:
     bool operator>=(const CardState &rhs) const { return it > rhs.it; }
     bool operator==(const CardState &rhs) const {
         return (it == rhs.it && source == rhs.source && x == rhs.x &&
-                y == rhs.y && z == rhs.z && faceup == rhs.faceup &&
-                i == rhs.i && tookdown == rhs.tookdown);
+                y == rhs.y && z == rhs.z && faceup == rhs.faceup
+                && source_index == rhs.source_index && tookdown == rhs.tookdown);
+    }
+    void fillNode(QDomElement &e) const {
+        e.setAttribute("value", it->value());
+        e.setAttribute("suit", it->suit());
+        e.setAttribute("source", source->index());
+        e.setAttribute("x", x);
+        e.setAttribute("y", y);
+        e.setAttribute("z", z);
+        e.setAttribute("faceup", faceup);
+        e.setAttribute("tookdown", tookdown);
+        e.setAttribute("source_index", source_index);
     }
-
 };
 
 typedef class QValueList<CardState> CardStateList;
@@ -620,46 +657,6 @@ bool operator==( const State & st1, const State & st2) {
     return st1.cards == st2.cards && st1.gameData == st2.gameData;
 }
 
-QDataStream& operator<<( QDataStream& s, const CardState& l ) {
-    s << Q_INT8(l.it->value());
-    s << Q_INT8(l.it->suit());
-    s << Q_INT8(l.source->index());
-    s << Q_INT16(l.x) << Q_INT16(l.y) << Q_INT16(l.z) << Q_INT8(l.faceup) << Q_INT8(l.tookdown) << Q_INT8(l.i);
-    return s;
-}
-
-void Dealer::loadCardState( QDataStream& s, CardState& l, CardList &toload) {
-    Q_INT8 v, suit;
-    s >> v >> suit;
-    l.it = 0;
-
-    for (CardList::Iterator it = toload.begin(); it != toload.end(); ++it)
-    {
-        if ((*it)->value() == v && (*it)->suit() == suit) {
-            l.it = *it;
-            toload.remove(it);
-            break;
-        }
-    }
-    assert(l.it);
-    Q_INT8 index;
-    s >> index;
-    l.source = 0;
-    for (PileList::Iterator it = piles.begin(); it != piles.end(); ++it)
-        if ((*it)->index() == index)
-            l.source = *it;
-    assert(l.source);
-    Q_INT8 tookdown, faceup, i;
-    Q_INT16 x, y, z;
-    s >> x >> y >> z >> faceup >> tookdown >> i;
-    l.tookdown = tookdown;
-    l.faceup = faceup;
-    l.x = x;
-    l.y = y;
-    l.z = z;
-    l.i = i;
-}
-
 State *Dealer::getState()
 {
     QCanvasItemList list = canvas()->allItems();
@@ -677,7 +674,7 @@ State *Dealer::getState()
                kdDebug(11111) << c->name() << " has no parent\n";
                assert(false);
            }
-           s.i = c->source()->indexOf(c);
+           s.source_index = c->source()->indexOf(c);
            s.x = c->realX();
            s.y = c->realY();
            s.z = c->realZ();
@@ -689,8 +686,7 @@ State *Dealer::getState()
     qHeapSort(st->cards);
 
     // Game specific information
-    QDataStream stream( st->gameData, IO_WriteOnly );
-    getGameState( stream );
+    st->gameData = getGameState( );
 
     return st;
 }
@@ -717,7 +713,7 @@ void Dealer::setState(State *st)
         Card *c = (*it).it;
         CardState s = *it;
         bool target = c->takenDown(); // abused
-        s.source->add(c, s.i);
+        s.source->add(c, s.source_index);
         c->setVisible(s.source->isVisible());
         c->setAnimated(false);
         c->setX(s.x);
@@ -728,8 +724,7 @@ void Dealer::setState(State *st)
     }
 
     // restore game-specific information
-    QDataStream stream( st->gameData, IO_ReadOnly );
-    setGameState(stream);
+    setGameState( st->gameData );
 
     delete st;
     canvas()->update();
@@ -755,68 +750,155 @@ void Dealer::takeState()
     }
 
     if (n) {
-		if (isGameLost()){
-			emit gameLost();	
-	    	return;
-			}
-        else if (isGameWon()) {
+        if (isGameWon()) {
             won();
             return;
-        } else if (!demoActive() && !waiting()) {
-            QTimer::singleShot(TIME_BETWEEN_MOVES, this, SLOT(startAutoDrop()));
+        }
+        else if (isGameLost()) {
+            QTimer::singleShot(400, this, SIGNAL(gameLost()));
+            return;
         }
     }
+    if (!demoActive() && !waiting())
+            QTimer::singleShot(TIME_BETWEEN_MOVES, this, SLOT(startAutoDrop()));
+
     emit undoPossible(undoList.count() > 1 && !waiting());
 }
 
-void Dealer::saveGame(QDataStream &s) {
-    s << 0; // file format
-    s << _id; // dealer number
-    s << Q_ULONG (gameNumber());
-    s << undoList.count();
-    QPtrListIterator<State> it(undoList);
+void Dealer::saveGame(QDomDocument &doc) {
+    QDomElement dealer = doc.createElement("dealer");
+    doc.appendChild(dealer);
+    dealer.setAttribute("id", _id);
+    dealer.setAttribute("number", QString::number(gameNumber()));
+    QString data = getGameState();
+    if (!data.isEmpty())
+        dealer.setAttribute("data", data);
 
+    bool taken[1000];
+    memset(taken, 0, sizeof(taken));
+
+    QCanvasItemList list = canvas()->allItems();
+    for (QCanvasItemList::Iterator it = list.begin(); it != list.end(); ++it)
+    {
+        if ((*it)->rtti() == Pile::RTTI) {
+            Pile *p = dynamic_cast<Pile*>(*it);
+            assert(p);
+            if (taken[p->index()]) {
+                kdDebug() << "pile index " << p->index() << " taken twice\n";
+                return;
+            }
+            taken[p->index()] = true;
+
+            QDomElement pile = doc.createElement("pile");
+            pile.setAttribute("index", p->index());
+
+            CardList cards = p->cards();
+            for (CardList::Iterator it = cards.begin();
+                 it != cards.end();
+                 ++it)
+            {
+                QDomElement card = doc.createElement("card");
+                card.setAttribute("suit", (*it)->suit());
+                card.setAttribute("value", (*it)->value());
+                card.setAttribute("faceup", (*it)->isFaceUp());
+                card.setAttribute("x", (*it)->realX());
+                card.setAttribute("y", (*it)->realY());
+                card.setAttribute("z", (*it)->realZ());
+                card.setAttribute("name", (*it)->name());
+                pile.appendChild(card);
+            }
+            dealer.appendChild(pile);
+        }
+    }
+
+    /*
+    QDomElement eList = doc.createElement("undo");
+
+    QPtrListIterator<State> it(undoList);
     for (; it.current(); ++it)
     {
         State *n = it.current();
-        s << n->gameData;
-        s << n->cards;
+        QDomElement state = doc.createElement("state");
+        if (!n->gameData.isEmpty())
+            state.setAttribute("data", n->gameData);
+        QDomElement cards = doc.createElement("cards");
+        for (QValueList<CardState>::ConstIterator it2 = n->cards.begin();
+             it2 != n->cards.end(); ++it2)
+        {
+            QDomElement item = doc.createElement("item");
+            (*it2).fillNode(item);
+            cards.appendChild(item);
+        }
+        state.appendChild(cards);
+        eList.appendChild(state);
     }
+    dealer.appendChild(eList);
+    */
+    // kdDebug() << doc.toString() << endl;
 }
 
-void Dealer::openGame(QDataStream &s)
+void Dealer::openGame(QDomDocument &doc)
 {
     unmarkAll();
-    Q_ULONG gn;
-    s >> gn;
-    setGameNumber(gn);
-    uint count;
-    s >> count;
+    QDomElement dealer = doc.documentElement();
+
+    setGameNumber(dealer.attribute("number").toULong());
     undoList.clear();
 
-    for (; count != 0; count--)
+    QDomNodeList piles = dealer.elementsByTagName("pile");
+
+    QCanvasItemList list = canvas()->allItems();
+
+    CardList cards;
+    for (QCanvasItemList::ConstIterator it = list.begin(); it != list.end(); ++it)
+        if ((*it)->rtti() == Card::RTTI)
+            cards.append(static_cast<Card*>(*it));
+
+    Deck::deck()->collectAndShuffle();
+
+    for (QCanvasItemList::Iterator it = list.begin(); it != list.end(); ++it)
     {
-        CardList cards;
-
-        QCanvasItemList list = canvas()->allItems();
-        for (QCanvasItemList::ConstIterator it = list.begin(); it != list.end(); ++it)
-            if ((*it)->rtti() == Card::RTTI)
-                cards.append(static_cast<Card*>(*it));
-
-        State *n = new State();
-        s >> n->gameData;
-        n->cards.clear();
-        Q_UINT32 c;
-        s >> c;
-        for( Q_UINT32 i = 0; i < c; ++i )
+        if ((*it)->rtti() == Pile::RTTI)
         {
-            CardState t;
-            loadCardState(s, t, cards);
-            n->cards.append( t );
+            Pile *p = dynamic_cast<Pile*>(*it);
+            assert(p);
+
+            for (uint i = 0; i < piles.count(); ++i)
+            {
+                QDomElement pile = piles.item(i).toElement();
+                if (pile.attribute("index").toInt() == p->index())
+                {
+                    QDomNodeList pcards = pile.elementsByTagName("card");
+                    for (uint j = 0; j < pcards.count(); ++j)
+                    {
+                        QDomElement card = pcards.item(j).toElement();
+                        Card::Suits s = static_cast<Card::Suits>(card.attribute("suit").toInt());
+                        Card::Values v = static_cast<Card::Values>(card.attribute("value").toInt());
+
+                        for (CardList::Iterator it2 = cards.begin();
+                             it2 != cards.end(); ++it2)
+                        {
+                            if ((*it2)->suit() == s && (*it2)->value() == v) {
+                                if (QString((*it2)->name()) == "Diamonds Eight") {
+                                    kdDebug() << i << " " << j << endl;
+                                }
+                                p->add(*it2);
+                                (*it2)->setAnimated(false);
+                                (*it2)->turn(card.attribute("faceup").toInt());
+                                (*it2)->setX(card.attribute("x").toInt());
+                                (*it2)->setY(card.attribute("y").toInt());
+                                (*it2)->setZ(card.attribute("z").toInt());
+                                (*it2)->setVisible(p->isVisible());
+                                cards.remove(it2);
+                                break;
+                            }
+                        }
+                    }
+                }
+            }
         }
-        assert(cards.isEmpty());
-        undoList.append(n);
     }
+    setGameState( dealer.attribute("data") );
 
     if (undoList.count() > 1) {
         setState(undoList.take(undoList.count() - 1));
@@ -865,11 +947,24 @@ void Dealer::setWaiting(bool w)
     kdDebug(11111) << "setWaiting " << w << " " << _waiting << endl;
 }
 
+void Dealer::setAutoDropEnabled(bool a) {
+    _autodrop = a;
+    QTimer::singleShot(TIME_BETWEEN_MOVES, this, SLOT(startAutoDrop()));
+}
+
 bool Dealer::startAutoDrop()
 {
-    if (movingCards.count())
+    if (!autoDrop())
         return false;
 
+    QCanvasItemList list = canvas()->allItems();
+
+    for (QCanvasItemList::ConstIterator it = list.begin(); it != list.end(); ++it)
+        if ((*it)->animated()) {
+            QTimer::singleShot(TIME_BETWEEN_MOVES, this, SLOT(startAutoDrop()));
+            return true;
+        }
+
     kdDebug(11111) << "startAutoDrop\n";
 
     unmarkAll();
@@ -1005,6 +1100,9 @@ MoveHint *Dealer::chooseHint()
 }
 
 void Dealer::demo() {
+    if (waiting())
+        return;
+
     if (stop_demo_next) {
         stopDemo();
         return;
@@ -1114,8 +1212,7 @@ bool Dealer::isGameWon() const
 
 bool Dealer::isGameLost() const
 {
-//PCG: assume not, let the individual games decide.
-	return false;
+    return false;
 }
 
 bool Dealer::checkRemove( int, const Pile *, const Card *) const {
@@ -1129,7 +1226,7 @@ bool Dealer::checkAdd( int, const Pile *, const CardList&) const {
 void Dealer::drawPile(KPixmap &pixmap, Pile *pile, bool selected)
 {
     QPixmap bg = myCanvas.backgroundPixmap();
-    QRect bounding(int(pile->x()), int(pile->y()), cardMap::CARDX, cardMap::CARDY);
+    QRect bounding(int(pile->x()), int(pile->y()), cardMap::CARDX(), cardMap::CARDY());
 
     pixmap.resize(bounding.width(), bounding.height());
     pixmap.fill(Qt::white);
@@ -1162,7 +1259,7 @@ void Dealer::drawPile(KPixmap &pixmap, Pile *pile, bool selected)
     }
 
 
-    float s = -0.1;
+    float s = -0.4;
     float n = -0.3;
 
     int mid = (midColor().red() + midColor().green() + midColor().blue()) / 3;
@@ -1193,6 +1290,21 @@ void Dealer::setAnchorName(const QString &name)
 
 QString Dealer::anchorName() const { return ac; }
 
+void Dealer::wheelEvent( QWheelEvent *e )
+{
+    QWheelEvent ce( viewport()->mapFromGlobal( e->globalPos() ),
+                    e->globalPos(), e->delta(), e->state());
+    viewportWheelEvent(&ce);
+    if ( !ce.isAccepted() ) {
+	if ( e->orientation() == Horizontal && hScrollBarMode () == AlwaysOn )
+	    QApplication::sendEvent( horizontalScrollBar(), e);
+	else  if (e->orientation() == Vertical && vScrollBarMode () == AlwaysOn )
+	    QApplication::sendEvent( verticalScrollBar(), e);
+    } else {
+	e->accept();
+    }
+}
+
 MoveHint::MoveHint(Card * c, Pile *_to, bool d)
 {
     _card = c; to = _to; _dropiftarget = d;
