@@ -1,8 +1,10 @@
 #include "fortyeight.h"
 #include <klocale.h>
+#include <kdebug.h>
 #include "deck.h"
 #include "pile.h"
 #include <assert.h>
+#include "cardmaps.h"
 
 HorLeftPile::HorLeftPile( int _index, Dealer* parent)
     : Pile(_index, parent)
@@ -20,23 +22,27 @@ QSize HorLeftPile::cardOffset( bool _spread, bool, const Card *) const
 Fortyeight::Fortyeight( KMainWindow* parent, const char* name)
         : Dealer(parent,name)
 {
-    deck = new Deck(0, this, 2);
+    deck = Deck::new_deck(this, 2);
+
+    const int dist_x = cardMap::CARDX() * 11 / 10 + 1;
+    const int dist_y = cardMap::CARDY() * 11 / 10 + 1;
+
     connect(deck, SIGNAL(clicked(Card*)), SLOT(deckClicked(Card*)));
-    deck->move(600, 450);
+    deck->move(10 + cardMap::CARDX() * 82 / 10, 10 + cardMap::CARDX() * 56 / 10);
     deck->setZ(20);
 
-    pile = new HorLeftPile(13, this);
+    pile = new HorLeftPile(20, this);
     pile->setAddFlags(Pile::addSpread | Pile::disallow);
-    pile->move(510, 450);
+    pile->move(10 + cardMap::CARDX() * 69 / 10, 10 + cardMap::CARDX() * 56 / 10 );
 
     for (int i = 0; i < 8; i++) {
 
         target[i] = new Pile(9 + i, this);
-        target[i]->move(8+80*i, 10);
+        target[i]->move(8+dist_x*i, 10);
         target[i]->setType(Pile::KlondikeTarget);
 
         stack[i] = new Pile(1 + i, this);
-        stack[i]->move(8+80*i, 110);
+        stack[i]->move(8+dist_x*i, 10 + dist_y);
         stack[i]->setAddFlags(Pile::addSpread);
         stack[i]->setRemoveFlags(Pile::autoTurnTop);
         stack[i]->setCheckIndex(1);
@@ -61,8 +67,11 @@ void Fortyeight::deckClicked(Card *)
         if (lastdeal)
             return;
         lastdeal = true;
-        while (!pile->isEmpty())
-            deck->add(pile->at(pile->cardsLeft()-1), true, false);
+        while (!pile->isEmpty()) {
+            Card *c = pile->at(pile->cardsLeft()-1);
+            c->setAnimated(false);
+            deck->add(c, true, false);
+        }
     }
     Card *c = deck->nextCard();
     pile->add(c, true, true);
@@ -107,22 +116,66 @@ void Fortyeight::deal()
     pile->add(deck->nextCard(), false, false);
 }
 
-void Fortyeight::getGameState( QDataStream & stream )
+QString Fortyeight::getGameState() const
 {
-    stream << (Q_INT8)lastdeal;
+    return QString::number(lastdeal);
 }
 
-void Fortyeight::setGameState( QDataStream & stream )
+void Fortyeight::setGameState( const QString &s )
 {
-    Q_INT8 i;
-    stream >> i;
-    lastdeal = i;
+    lastdeal = s.toInt();
+}
+
+bool Fortyeight::isGameLost() const{
+   kdDebug(11111) << "isGameLost ?" << endl;
+   if(!lastdeal)
+	return false;
+   if(!deck->isEmpty())
+	return false;
+
+   Card *c;
+   for(int i=0; i < 8; i++){
+	if(stack[i]->isEmpty())
+		return false;
+	c=stack[i]->top();
+
+	if(c->value() == Card::Ace)
+		return false;
+	if(!pile->isEmpty())
+		if(pile->top()->suit() == c->suit() &&
+			pile->top()->value()-1 == c->value())
+			return false;
+	for(int j=0; j <8;j++){
+		if(target[j]->isEmpty())
+			continue;
+		if(c->suit() == target[j]->top()->suit() &&
+			c->value()-1 ==target[j]->top()->value())
+			return false;
+		}
+	for(int j=1; j < 8; j++){
+		int k=(i+j) % 8;
+		if (stack[k]->isEmpty())
+			continue;
+		if(c->suit() == stack[k]->top()->suit() &&
+			c->value()+1 ==stack[k]->top()->value()){
+			int indexi=stack[i]->indexOf(c);
+			if(indexi==0)
+				return false;
+			Card *c2=stack[i]->at(indexi-1);
+			if(c2->value()!=stack[k]->top()->value() ||
+				c2->suit()!=stack[k]->top()->suit())
+				return false;
+			}
+		}
+	}
+
+   return true;
 }
 
 static class LocalDealerInfo8 : public DealerInfo
 {
 public:
-    LocalDealerInfo8() : DealerInfo(I18N_NOOP("F&orty and Eight"), 8) {}
+    LocalDealerInfo8() : DealerInfo(I18N_NOOP("Forty && &Eight"), 8) {}
     virtual Dealer *createGame(KMainWindow *parent) { return new Fortyeight(parent); }
 } ldi9;
 
