@@ -3,6 +3,7 @@
 #include "deck.h"
 #include "pile.h"
 #include <kdebug.h>
+#include "cardmaps.h"
 
 HorRightPile::HorRightPile( int _index, Dealer* parent)
     : Pile(_index, parent)
@@ -22,19 +23,22 @@ QSize HorRightPile::cardOffset( bool _spread, bool, const Card *) const
 Golf::Golf( KMainWindow* parent, const char* _name)
         : Dealer( parent, _name )
 {
-    deck = new Deck( 0, this);
-    deck->move(30, 300);
+    const int dist_x = cardMap::CARDX() * 11 / 10 + 1;
+    const int pile_dist = 10 + 3 * cardMap::CARDY();
+
+    deck = Deck::new_deck( this);
+    deck->move(10, pile_dist);
     connect(deck, SIGNAL(clicked(Card*)), SLOT(deckClicked(Card*)));
 
     for( int r = 0; r < 7; r++ ) {
         stack[r]=new Pile(1+r, this);
-        stack[r]->move(30+r*90,10);
+        stack[r]->move(10+r*dist_x,10);
         stack[r]->setAddFlags( Pile::addSpread | Pile::disallow);
         stack[r]->setCheckIndex( 1 );
     }
 
     waste=new HorRightPile(8,this);
-    waste->move(120,300);
+    waste->move(10 + cardMap::CARDX() * 5 / 4, pile_dist);
     waste->setTarget(true);
     waste->setCheckIndex( 0 );
     waste->setAddFlags( Pile::addSpread);
@@ -56,25 +60,6 @@ bool Golf::checkAdd( int checkIndex, const Pile *c1, const CardList& cl) const
     if ((c2->value() != (c1->top()->value()+1)) && (c2->value() != (c1->top()->value()-1)))
         return false;
 
-
-    return true;
-
-}
-
-bool Golf::isGameLost() const
-{
-	if( !deck->isEmpty())
-		return false;
-
-	for( int r = 0; r < 7; r++ ) {
-		if( !stack[r]->isEmpty()){
-			CardList stackTops;
-			stackTops.append(stack[r]->top());
-			if(this->checkAdd(0,waste,stackTops))
-				return false;
-			}
-		}
-			
     return true;
 }
 
@@ -128,31 +113,52 @@ Card *Golf::demoNewCards()
     return waste->top();
 }
 
-void Golf::cardClicked(Card *c)
+bool Golf::cardClicked(Card *c)
 {
     if (c->source()->checkIndex() !=1) {
-        Dealer::cardClicked(c);
-        return;
+        return Dealer::cardClicked(c);
     }
 
     if (c != c->source()->top())
-        return;
+        return false;
 
     Pile*p=findTarget(c);
-    if(p)
+    if (p)
     {
         CardList empty;
         empty.append(c);
         c->source()->moveCards(empty, p);
         canvas()->update();
+        return true;
     }
+    return false;
+}
+
+bool Golf::isGameLost() const
+{
+    if( !deck->isEmpty())
+        return false;
+
+    bool onecard = false;
+
+    for( int r = 0; r < 7; r++ ) {
+        if( !stack[r]->isEmpty()){
+            onecard = true;
+            CardList stackTops;
+            stackTops.append(stack[r]->top());
+            if(this->checkAdd(0,waste,stackTops))
+                return false;
+        }
+    }
+
+    return onecard;
 }
 
 
 static class LocalDealerInfo13 : public DealerInfo
 {
 public:
-    LocalDealerInfo13() : DealerInfo(I18N_NOOP("G&olf"), 13) {}
+    LocalDealerInfo13() : DealerInfo(I18N_NOOP("Go&lf"), 13) {}
     virtual Dealer *createGame(KMainWindow *parent) { return new Golf(parent); }
 } ldi13;
 
