@@ -24,26 +24,29 @@
 #include <klocale.h>
 #include <deck.h>
 #include <pile.h>
+#include "cardmaps.h"
 
 Idiot::Idiot( KMainWindow* parent, const char* _name)
   : Dealer( parent, _name )
 {
-    deck = new Deck( 0, this );
+    deck = Deck::new_deck( this );
     deck->move(10, 10);
 
     away = new Pile( 5, this );
     away->setTarget(true);
     away->setRemoveFlags(Pile::disallow);
 
+    const int distx = cardMap::CARDX() + cardMap::CARDX() / 10 + 1;
+
     for( int i = 0; i < 4; i++ )
     {
         play[ i ] = new Pile( i + 1, this);
-        play[i]->move(150 + 85 * i, 10);
+        play[i]->move(10 + cardMap::CARDX() * 18 / 10 + distx * i, 10);
         play[i]->setAddFlags( Pile::addSpread );
         play[i]->setRemoveFlags( Pile::disallow );
     }
 
-    away->move(200 + 85 * 4, 10);
+    away->move(10 + cardMap::CARDX() * 5 / 2 + distx * 4, 10);
     setActions(Dealer::Hint | Dealer::Demo);
 
 }
@@ -75,15 +78,15 @@ bool Idiot::canMoveAway(Card *c)
              higher( c, play[ 3 ]->top() ) );
 }
 
-void Idiot::cardClicked(Card *c)
+bool Idiot::cardClicked(Card *c)
 {
     if (c->source() == deck) {
         deal();
-        return;
+        return true;
     }
 
     if (c != c->source()->top())
-        return;
+        return false;
 
     if( canMoveAway(c) )
         away->add(c, false, false);
@@ -95,6 +98,8 @@ void Idiot::cardClicked(Card *c)
         play[2]->add( c, false, true);
     else if( play[ 3 ]->isEmpty() )
         play[3]->add(c, false, true);
+
+    return true; // may be a lie, but noone cares
 }
 
 bool Idiot::isGameWon() const
@@ -109,8 +114,9 @@ bool Idiot::isGameWon() const
     return true;
 }
 
-void Idiot::cardDblClicked(Card *)
+bool Idiot::cardDblClicked(Card *)
 {
+    return false; // nothing - nada
 }
 
 void Idiot::deal()
