@@ -33,16 +33,18 @@ public:
     Mod3( KMainWindow* parent=0, const char* name=0);
     void deal();
     virtual void restart();
+    virtual bool isGameLost() const;
+    virtual bool startAutoDrop();
 
 public slots:
     void deckClicked(Card *c);
 
 protected:
-    virtual bool startAutoDrop() { return false; }
     virtual Card *demoNewCards();
 
 private: // functions
     virtual bool checkAdd( int checkIndex, const Pile *c1, const CardList& c2) const;
+    virtual bool checkPrefering( int checkIndex, const Pile *c1, const CardList& c2) const;
     void dealRow(int row);
 
 private:
