@@ -83,6 +83,7 @@ public:
     virtual QSize cardOffset( bool _spread, bool _facedown, const Card *before) const;
 
     void resetCache();
+    void initSizes();
 
     enum PileType { Custom, KlondikeTarget, KlondikeStore, GypsyStore, FreeCell, FreecellStore};
     void setType( PileType t);
@@ -107,8 +108,8 @@ public:
     void setHSpread(int s) { _hspread = s; }
 
 public slots:
-    virtual void cardClicked(Card *c);
-    virtual void cardDblClicked(Card *c);
+    virtual bool cardClicked(Card *c);
+    virtual bool cardDblClicked(Card *c);
 
 signals:
     void clicked(Card *c);
