@@ -33,7 +33,7 @@
 #include <kdebug.h>
 #include "cardmaps.h"
 #include <kcarddialog.h>
-#include <qinputdialog.h>
+#include <klineeditdlg.h>
 #include <kstandarddirs.h>
 #include <kfiledialog.h>
 #include <ktempfile.h>
@@ -41,7 +41,7 @@
 #include "speeds.h"
 #include <kmessagebox.h>
 #include <qimage.h>
-#include <kstatusbar.h>  
+#include <kstatusbar.h>
 
 static pWidget *current_pwidget = 0;
 
@@ -71,7 +71,7 @@ pWidget::pWidget( const char* _name )
                            actionCollection(), "save");
     (void)new KAction(i18n("&Choose Game..."), 0, this, SLOT(chooseGame()),
                       actionCollection(), "choose_game");
-    (void)new KAction(i18n("&Restart Game"), QString::fromLatin1("reload"), 0,
+    (void)new KAction(i18n("Restart &Game"), QString::fromLatin1("reload"), 0,
                       this, SLOT(restart()),
                       actionCollection(), "restart_game");
     (void)KStdAction::help(this, SLOT(helpGame()), actionCollection(), "help_game");
@@ -120,22 +120,30 @@ pWidget::pWidget( const char* _name )
     animation = new KToggleAction(i18n( "&Animation on Startup" ),
                                   0, this, SLOT(animationChanged()),
                                   actionCollection(), "animation");
+    dropaction = new KToggleAction(i18n("&Enable Autodrop"),
+                                   0, this, SLOT(enableAutoDrop()),
+                                   actionCollection(), "enable_autodrop");
 
     KConfig *config = kapp->config();
     KConfigGroupSaver cs(config, settings_group );
 
     QString bgpath = config->readEntry("Background");
-    if (!bgpath.isNull())
-         background = QPixmap(bgpath);
+    kdDebug() << "bgpath '" << bgpath << "'" << endl;
+    if (bgpath.isEmpty())
+        bgpath = locate("wallpaper", "Totally-New-Product-1.jpg");
+    background = QPixmap(bgpath);
 
     bool animate = config->readBoolEntry( "Animation", true);
     animation->setChecked( animate );
 
+    bool autodrop = config->readBoolEntry("Autodrop", true);
+    dropaction->setChecked(autodrop);
+
     uint game = config->readNumEntry("DefaultGame", 0);
     if (game > max_type)
         game = max_type;
     games->setCurrentItem(game);
-    
+
     createGUI(QString::null, false);
 
     newGameType();
@@ -168,25 +176,48 @@ void pWidget::changeBackside() {
     KConfigGroupSaver kcs(config, settings_group);
 
     QString deck = config->readEntry("Back");
-    QString dummy = config->readEntry("Cards");
-    if (KCardDialog::getCardDeck(deck, dummy, this, KCardDialog::Both) == QDialog::Accepted)
+    QString cards = config->readEntry("Cards");
+    if (KCardDialog::getCardDeck(deck, cards, this, KCardDialog::Both) == QDialog::Accepted)
     {
-        setBackSide(deck, dummy);
+        QString imgname = KCardDialog::getCardPath(cards, 11);
+
+        QImage image;
+        image.load(imgname);
+        if( image.isNull()) {
+            kdDebug(11111) << "cannot load card pixmap \"" << imgname << "\" in " << cards << "\n";
+            return;
+        }
+
+        bool change = false;
+        if (image.width() != cardMap::CARDX() || image.height() != cardMap::CARDY())
+        {
+            change = true;
+            if (KMessageBox::warningContinueCancel(this, i18n("The cards you have chosen have a different "
+                                                              "size than the ones you are currently using. "
+                                                              "This requires the current game to be restarted.")) == KMessageBox::Cancel)
+                return;
+        }
+        setBackSide(deck, cards);
+        if (change) {
+
+            newGameType();
+        }
     }
+
 }
 
 void pWidget::changeWallpaper()
 {
     QString bgpath=locate("wallpaper", wallpaperlist[wallpapers->currentItem()]);
-	if (bgpath.isEmpty())
-			return;
+    if (bgpath.isEmpty())
+        return;
     background = QPixmap(bgpath);
-	if (background.isNull())
-			return;
+    if (background.isNull())
+        return;
 
     QImage bg = background.convertToImage().convertDepth(8, 0);
-	if (bg.isNull() || !bg.numColors())
-			return;
+    if (bg.isNull() || !bg.numColors())
+        return;
     long r = 0;
     long g = 0;
     long b = 0;
@@ -206,8 +237,8 @@ void pWidget::changeWallpaper()
         KConfig *config = kapp->config();
         KConfigGroupSaver kcs(config, settings_group);
 
-        QString deck = config->readEntry("Back");
-        QString dummy = config->readEntry("Cards");
+        QString deck = config->readEntry("Back", KCardDialog::getDefaultDeck());
+        QString dummy = config->readEntry("Cards", KCardDialog::getDefaultCardDir());
         setBackSide(deck, dummy);
 
 	config->writeEntry("Background", bgpath);
@@ -224,6 +255,15 @@ void pWidget::animationChanged() {
     config->writeEntry( "Animation", anim);
 }
 
+void pWidget::enableAutoDrop()
+{
+    bool drop = dropaction->isChecked();
+    KConfig *config = kapp->config();
+    KConfigGroupSaver cs(config, settings_group );
+    config->writeEntry( "Autodrop", drop);
+    dill->setAutoDropEnabled(drop);
+}
+
 void pWidget::newGame() {
     dill->setGameNumber(kapp->random());
     restart();
@@ -262,6 +302,8 @@ void pWidget::newGameType()
     connect(dill, SIGNAL(gameWon(bool)), SLOT(gameWon(bool)));
     connect(dill, SIGNAL(gameLost()), SLOT(gameLost()));
 
+    dill->setAutoDropEnabled(dropaction->isChecked());
+
     // it's a bit tricky - we have to do this here as the
     // base class constructor runs before the derived class's
     dill->takeState();
@@ -309,7 +351,7 @@ void pWidget::setBackSide(const QString &deck, const QString &cards)
     KConfigGroupSaver kcs(config, settings_group);
     QPixmap pm(deck);
     if(!pm.isNull()) {
-        cardMap::self()->setBackSide(pm);
+        cardMap::self()->setBackSide(pm, false);
         config->writeEntry("Back", deck);
         bool ret = cardMap::self()->setCardDir(cards);
         if (!ret) {
@@ -317,6 +359,7 @@ void pWidget::setBackSide(const QString &deck, const QString &cards)
 
         }
         config->writeEntry("Cards", cards);
+        cardMap::self()->setBackSide(pm, true);
     } else
         KMessageBox::sorry(this,
                            i18n("Could not load background image!"));
@@ -329,14 +372,12 @@ void pWidget::setBackSide(const QString &deck, const QString &cards)
 
 void pWidget::chooseGame()
 {
-    bool ok = false;
-    QString text = QInputDialog::getText( i18n("Game Number"),
-                                          i18n( "Enter a game number "
-                                                "(1 to 32000 are the same as in the FreeCell FAQ)" ),
-                                          QLineEdit::Normal, 
-                                          QString::number(dill->gameNumber()), &ok, this );
-    if ( ok && !text.isEmpty() ) {
-        long number = text.toLong(&ok);
+    KLineEditDlg dlg(i18n("Enter a game number (1 to 32000 are the same as in the FreeCell FAQ):"), QString::number(dill->gameNumber()), this);
+    dlg.setCaption(i18n("Game Number"));
+
+    bool ok;
+    if (dlg.exec()) {
+        long number = dlg.text().toLong(&ok);
         if (ok) {
             dill->setGameNumber(number);
             restart();
@@ -362,13 +403,12 @@ void pWidget::gameWon(bool withhelp)
 
 void pWidget::gameLost()
 {
-	QString sorry;
-
-	sorry=i18n("Game Lost.");
-    KMessageBox::information(this, sorry, i18n("Sorry"));
-    QTimer::singleShot(0, this, SLOT(newGame()));
-}
-
+    if (KMessageBox::questionYesNo(this, i18n("You couldn't win this game, "
+                                              "but there is always a second try.\nStart a new game?"),
+                                   i18n("Couldn't Win!"),
+                                   i18n("New Game"), i18n("Continue")) == KMessageBox::Yes)
+        QTimer::singleShot(0, this, SLOT(newGame()));
+ }
 
 void pWidget::openGame(const KURL &url)
 {
@@ -377,13 +417,16 @@ void pWidget::openGame(const KURL &url)
     {
         QFile of(tmpFile);
         of.open(IO_ReadOnly);
-        QDataStream is(&of);
-        int current_file_format;
-        is >> current_file_format; // file format
-        is.setVersion(current_file_format);
-        int id;
-        is >> id; // dealer number
-        if (id != games->currentItem()) {
+        QDomDocument doc;
+        QString error;
+        if (!doc.setContent(&of, &error))
+        {
+            KMessageBox::sorry(this, error);
+            return;
+        }
+        uint id = doc.documentElement().attribute("id").toUInt();
+
+        if (id != (Q_UINT32)games->currentItem()) {
             games->setCurrentItem(id);
             newGameType();
             if (!dill) {
@@ -392,7 +435,7 @@ void pWidget::openGame(const KURL &url)
                 newGameType();
             }
         }
-        dill->openGame(is);
+        dill->openGame(doc);
         KIO::NetAccess::removeTempFile( tmpFile );
         recent->addURL(url);
         recent->saveEntries(KGlobal::config());
@@ -409,8 +452,10 @@ void pWidget::saveGame()
 {
     KURL url = KFileDialog::getSaveURL();
     KTempFile file;
-    QDataStream *stream = file.dataStream();
-    dill->saveGame(*stream);
+    QDomDocument doc("kpat");
+    dill->saveGame(doc);
+    QTextStream *stream = file.textStream();
+    *stream << doc.toString();
     file.close();
     KIO::NetAccess::upload(file.name(), url);
     recent->addURL(url);
