@@ -18,9 +18,7 @@
 #include <stdlib.h>
 
 // QT includes
-#include <qpushbutton.h>
 #include <qlabel.h>
-//#include <qpopupmenu.h>
 #include <qtimer.h>
 #include <qpainter.h>
 #include <qtooltip.h>
@@ -30,12 +28,9 @@
 #include <kmessagebox.h>
 #include <kapplication.h>
 #include <kglobal.h>
-#include <kmenubar.h>
-#include <kstdaccel.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 #include <kconfig.h>
-#include <kaccel.h>
 #include <klocale.h>
 #include <kaudioplayer.h>
 #include <kcarddialog.h>
@@ -66,6 +61,8 @@ kpok::kpok(QWidget *parent, const char *name) : QWidget(parent, name)
 
 	mOptions = 0;
 	newGameDlg = 0;
+	playerBox = 0;
+	adjust = false;
 
 	initSomeStuff();
 	initSound();
@@ -92,10 +89,9 @@ kpok::~kpok()
 // conf->writeEntry("CashPerRound", cashPerRound);
  conf->writeEntry("DrawDelay", drawDelay);
 
- delete kacc;
  for (int i = 0; i < allPlayersNr; i++)
  	delete playerBox[i];
- delete playerBox;// necessary?
+ delete[] playerBox;// necessary?
  delete[] allPlayers;
  delete[] done;
  if (mOptions != 0)
@@ -118,7 +114,7 @@ void kpok::newGame()
 	for (int i = 0; i < allPlayersNr; i++)
 		delete playerBox[i];
 	delete[] allPlayers;
-	delete playerBox;// necessary?
+	delete[] playerBox;// necessary?
 
 	player.clear();
 	removedPlayers.clear();
@@ -324,7 +320,7 @@ void kpok::out()
  pot += (oldBet_raise - findHumanPlayer()->getCurrentBet());
  findHumanPlayer()->changeBet(oldBet_raise - findHumanPlayer()->getCurrentBet());
  paintCash();
- drawButton->setText(i18n("&Draw!"));
+ drawButton->setText(i18n("&Draw"));
 }
 
 void kpok::adjustBet()
@@ -547,7 +543,7 @@ void kpok::drawClick()
  }
  else if (getStatus() == statSee) {
 	winner();
- 	drawButton->setText(i18n("&Draw!"));
+ 	drawButton->setText(i18n("&Draw"));
  }
 }
 
@@ -1159,8 +1155,9 @@ void kpok::loadCards(QString cardDir)
 {
  for (int i = 0; i < highestCard; i++) {
 	QString card = KCardDialog::getCardPath(cardDir, i + 1);
-	if (!cardImage->cardP[i].load(card)) {
-		kdWarning() << "Could not load " << card << " trying default" << endl;
+	if (card.isEmpty() || !cardImage->cardP[i].load(card)) {
+		if (!card.isEmpty())
+			kdWarning() << "Could not load " << card << " trying default" << endl;
 		card = KCardDialog::getCardPath(KCardDialog::getDefaultCardDir(), i+1);
 		if (!cardImage->cardP[i].load(card)) {
 			kdError() << "Could not load " << card << endl;
@@ -1175,6 +1172,9 @@ void kpok::loadCards(QString cardDir)
 
 void kpok::loadDeck(QString path)
 {
+ if (playerBox && blinking && (blinkStat == 0))
+	bTimerEvent();
+
  if (!cardImage->deck.load(path)) {
 	kdWarning() << "Could not load deck - loading default deck" << endl;
 	path = KCardDialog::getDefaultDeck();
