@@ -15,7 +15,6 @@
  */
 
 // QT includes
-#include <qpushbutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
@@ -63,19 +62,19 @@ NewGameDlg::NewGameDlg(QWidget* parent) : KDialogBase(Plain, i18n("New Game"),
  topLayout->addWidget(players);
 
  l = new QHBoxLayout(topLayout);
- l->addWidget(new QLabel(i18n("Your Name"), plainPage()));
+ l->addWidget(new QLabel(i18n("Your name:"), plainPage()));
  player1Name = new QLineEdit(plainPage());
  l->addWidget(player1Name);
 
  l = new QHBoxLayout(topLayout);
- l->addWidget(new QLabel(i18n("Start money of the players"), plainPage()));
+ l->addWidget(new QLabel(i18n("Players' starting money:"), plainPage()));
  moneyOfPlayers = new QLineEdit(QString("%1").arg(money), plainPage());
  moneyOfPlayers->setValidator( new KIntValidator( 0,999999,moneyOfPlayers ) );
 
  l->addWidget(moneyOfPlayers);
 
  l = new QHBoxLayout(topLayout);
- l->addWidget(new QLabel(i18n("The names of your enemies"), plainPage()));
+ l->addWidget(new QLabel(i18n("The names of your opponents:"), plainPage()));
  computerNames = new QComboBox(true, plainPage());
  computerNames->setInsertionPolicy(QComboBox::AtCurrent);
  l->addWidget(computerNames);
