@@ -41,6 +41,7 @@
 
 #include <math.h>
 #include <stdio.h>
+#include <algorithm>
 
 #include <qlayout.h>
 #include <qtimer.h>
@@ -61,13 +62,12 @@
 #include <kstdgameaction.h>
 #include <khighscore.h>
 #include <kdebug.h>
+#include <kkeydialog.h>
 
 static int size_x[5] = {14, 18, 24, 26, 30};
 static int size_y[5] = { 6,  8, 12, 14, 16};
 static int DELAY[5] = {125, 250, 500, 750, 1000};
 
-extern int MAX(int, int);
-
 App::App() : KMainWindow(0) {
   setCaption(i18n("Shisen-Sho"));
   highscoreTable = new KHighscore();
@@ -78,17 +78,16 @@ App::App() : KMainWindow(0) {
   }
 
   cheat = FALSE;
-  
 
   initKAction();
 
-  b = new Board(this);  
+  b = new Board(this);
   setCentralWidget(b);
 
-  sb = new KStatusBar(this);
-  sb->insertItem(i18n("Your time: XX:XX:XX (XXXXXXXXXXXXXXX)"), 1);
-  sb->insertItem(i18n("Cheat mode"), 2);
-  sb->changeItem("", 2);
+  statusBar()->insertItem("", SBI_TIME);
+  statusBar()->insertItem("", SBI_TILES);
+  statusBar()->insertFixedItem(i18n(" Cheat mode "), SBI_CHEAT);
+  statusBar()->changeItem("", SBI_CHEAT);
 
   connect(b, SIGNAL(changed()),
 	  this, SLOT(enableItems()));
@@ -108,13 +107,11 @@ App::App() : KMainWindow(0) {
   //kdDebug() << "CUSTOM SIZE, TODO" << endl;
   //  else
   ((KSelectAction*)actionCollection()->action("options_size"))->setCurrentItem(i - 300);
-  changeSize();
 
   QTimer *t = new QTimer(this);
   t->start(1000);
   connect(t, SIGNAL(timeout()),
 	  this, SLOT(updateScore()));
-  updateScore();
 
   connect(b, SIGNAL(endOfGame()),
  	  this, SLOT(slotEndOfGame()));
@@ -129,17 +126,17 @@ App::App() : KMainWindow(0) {
   ((KToggleAction*)actionCollection()->action("options_gravity"))->setChecked(_b);
 
   kapp->processEvents();
-  i = conf->readNumEntry("Level", 311 + 1);
-  ((KSelectAction*)actionCollection()->action("options_level"))->setCurrentItem(i - 311);
-  changeLevel();
+  i = conf->readNumEntry("Level", 311 + 1) - 311;
+  ((KSelectAction*)actionCollection()->action("options_level"))->setCurrentItem(i);
+  b->setShuffle(i * 4 + 1);
 
-  sizeChanged();
+  changeSize();
+  updateScore();
   enableItems();
 }
 
 App::~App() {
   delete b;
-  delete sb;
   delete highscoreTable;
 
 }
@@ -175,11 +172,11 @@ void App::initKAction() {
 
   list.clear();
   KSelectAction* speed = new KSelectAction(i18n("S&peed"), 0, this, SLOT(changeSpeed()), actionCollection(), "options_speed");
-  list.append(i18n("Very fast"));
+  list.append(i18n("Very Fast"));
   list.append(i18n("Fast"));
   list.append(i18n("Medium"));
   list.append(i18n("Slow"));
-  list.append(i18n("Very slow"));
+  list.append(i18n("Very Slow"));
   speed->setItems(list);
 
   list.clear();
@@ -191,6 +188,8 @@ void App::initKAction() {
 
   (void)new KToggleAction(i18n("G&ravity"), 0, this, SLOT(toggleGravity()), actionCollection(), "options_gravity");
   (void)new KToggleAction(i18n("Disallow Unsolvable Games"), 0, this, SLOT(toggleDisallowUnsolvable()), actionCollection(), "options_disallow");
+
+  KStdAction::keyBindings(this, SLOT(keyBindings()), actionCollection());
   
   createGUI("kshisenui.rc");
 }
@@ -201,8 +200,7 @@ void App::hallOfFame() {
 
 void App::newGame() {
   b->newGame();
-  cheat = FALSE;
-  sb->changeItem("", 2);
+  resetCheatMode();
   enableItems();
 }
 
@@ -223,10 +221,10 @@ void App::restartGame() {
 void App::isSolvable() {
   if(b->solvable())
 	KMessageBox::information(this,
-				i18n("This game is solveable"));
+				i18n("This game is solvable."));
   else
 	KMessageBox::information(this,
-				 i18n("This game is NOT solveable"));
+				 i18n("This game is NOT solvable."));
 }
 
 void App::pause() {
@@ -236,20 +234,18 @@ void App::pause() {
 	actionCollection()->action("game_pause")->setText(i18n("R&esume game"));
   else
 	actionCollection()->action("game_pause")->setText(i18n("&Pause game"));
-  actionCollection()->action("game_pause")->setAccel(Qt::Key_P);
 }
 
 void App::undo() {
   if(b->canUndo()) {
     b->undo();
-    cheat = TRUE;
-    sb->changeItem(i18n("Cheat mode"), 2);
+    setCheatMode();
     enableItems();
   }
 }
 
 void App::redo() {
-  if(b->canRedo()) 
+  if(b->canRedo())
     b->redo();
     enableItems();
 }
@@ -259,14 +255,13 @@ void App::hint() {
   b->makeHintMove();
 #else
   b->getHint();
-  cheat = TRUE;
-  sb->changeItem(i18n("Cheat mode"), 2);
+  setCheatMode();
 #endif
   enableItems();
 }
 
 void App::toggleGravity() {
-  if(!b->canUndo()) {
+  if(!b->canUndo() && !b->canRedo()) {
     b->setGravityFlag(!b->gravityFlag());
     kapp->config()->writeEntry("Gravity", (int)b->gravityFlag());
   } else {
@@ -288,7 +283,7 @@ void App::changeSpeed() {
 void App::changeSize() {
   int index = ((KSelectAction*)actionCollection()->action("options_size"))->currentItem();
   b->setSize(size_x[index], size_y[index]);
-  b->newGame();
+  resetCheatMode();  
   kapp->config()->writeEntry("Size", 300 + index);// 300 is from the old QPopuMenu+ID way - before KAction
 }
 
@@ -296,6 +291,7 @@ void App::changeLevel() {
   int index = ((KSelectAction*)actionCollection()->action("options_level"))->currentItem();
   b->setShuffle(index * 4 + 1);
   b->newGame();
+  resetCheatMode();
   kapp->config()->writeEntry("Level", 311 + index); // 311 is from the old QPopuMenu+ID way - before KAction
 }
 
@@ -323,7 +319,7 @@ void App::enableItems() {
     actionCollection()->action(KStdAction::stdName(KStdAction::Undo))->setEnabled(b->canUndo());
     actionCollection()->action(KStdAction::stdName(KStdAction::Redo))->setEnabled(b->canRedo());
     actionCollection()->action("game_restart")->setEnabled(b->canUndo());
-    actionCollection()->action("options_gravity")->setEnabled(!b->canUndo());
+    actionCollection()->action("options_gravity")->setEnabled(!b->canUndo() && !b->canRedo());
     ((KToggleAction*)actionCollection()->action("options_gravity"))->setChecked(b->gravityFlag());
   }
 }
@@ -339,7 +335,7 @@ void App::slotEndOfGame() {
   if(b->tilesLeft() > 0)
       KMessageBox::information(this,
 			       i18n("No more moves possible!"),
-			       i18n("End of game"));
+			       i18n("End of Game"));
   else {
     // create highscore entry
     HighScore hs;
@@ -356,11 +352,8 @@ void App::slotEndOfGame() {
       isHighscore = TRUE;
 
     if(isHighscore) {
-      QString name = getPlayerName();
-      strncpy(hs.name, name.utf8(), sizeof(hs.name) - 1);
+      hs.name = getPlayerName();
       hs.date = time((time_t*)0);
-      hs.x = b->x_tiles();
-      hs.y = b->y_tiles();
       int rank = insertHighscore(hs);
       showHighscore(rank);
     } else {
@@ -368,30 +361,58 @@ void App::slotEndOfGame() {
 		.arg(QString().sprintf("%02d", b->getTimeForGame()/3600))
 		.arg(QString().sprintf("%02d", (b->getTimeForGame() / 60) % 60))
 		.arg(QString().sprintf("%02d", b->getTimeForGame() % 60));
-      
-      KMessageBox::information(this, s, i18n("End of game"));
+
+      KMessageBox::information(this, s, i18n("End of Game"));
     }
   }
 
-  cheat = FALSE;
-  sb->changeItem("", 2);
+  resetCheatMode();
   b->newGame();
 }
 
 void App::updateScore() {
-  QString s = i18n("Your time: %1:%2:%3 %4")
-		.arg(QString().sprintf("%02d", b->getTimeForGame()/3600))
-		.arg(QString().sprintf("%02d", (b->getTimeForGame() / 60) % 60))
-		.arg(QString().sprintf("%02d", b->getTimeForGame() % 60))
-		.arg(b->isPaused()?i18n(" (Paused)"):QString::null);
 
-  sb->changeItem(s, 1);
+  int t = b->getTimeForGame();
+  QString s = i18n(" Your time: %1:%2:%3%4 ")
+		.arg(QString().sprintf("%02d", t / 3600 ))
+		.arg(QString().sprintf("%02d", (t / 60) % 60 ))
+		.arg(QString().sprintf("%02d", t % 60 ))
+		.arg(b->isPaused()?i18n("(Paused) "):QString::null);
+  statusBar()->changeItem(s, SBI_TIME);
+  
+  // Number of tiles
+  int tl = (b->x_tiles() * b->y_tiles());
+  s = i18n(" Removed: %1/%2 ") 
+		.arg(QString().sprintf("%d", tl - b->tilesLeft()))
+		.arg(QString().sprintf("%d", tl ));
+  statusBar()->changeItem(s, SBI_TILES);
+      
 }
 
-QString App::getPlayerName() {
-  QDialog *dlg = new QDialog(this, "Hall Of Fame", TRUE);
+void App::setCheatMode() {
+  
+  // set the cheat mode if not set
+  if (!cheat) {
+   	cheat = TRUE;
+   	statusBar()->changeItem(i18n(" Cheat mode "), SBI_CHEAT);
+  } 
 
-  QLabel  *l1  = new QLabel(i18n("You've made in into the \"Hall Of Fame\".Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
+}
+
+void App::resetCheatMode() {
+  
+  // reset cheat mode if set
+  if (cheat) {
+  	cheat = FALSE;
+  	statusBar()->changeItem("", SBI_CHEAT);
+  }
+
+} 
+ 
+QString App::getPlayerName() {
+  QDialog *dlg = new QDialog(this, "Hall of Fame", TRUE);
+
+  QLabel  *l1  = new QLabel(i18n("You've made it into the \"Hall Of Fame\". Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
   l1->setFixedSize(l1->sizeHint());
 
   QLabel *l2 = new QLabel(i18n("Your name:"), dlg);
@@ -401,7 +422,7 @@ QString App::getPlayerName() {
   e->setText("XXXXXXXXXXXXXXXX");
   e->setMinimumWidth(e->sizeHint().width());
   e->setFixedHeight(e->sizeHint().height());
-  e->setText("");
+  e->setText( lastPlayerName );
   e->setFocus();
 
   QPushButton *b = new QPushButton(i18n("OK"), dlg);
@@ -432,15 +453,15 @@ QString App::getPlayerName() {
 
   dlg->exec();
 
-  QString s = e->text();
+  lastPlayerName = e->text();
   delete dlg;
 
-  if(s.length() == 0)
-    s = " ";
-  return s;
+  if(lastPlayerName.isEmpty())
+    return " ";
+  return lastPlayerName;
 }
 
-int App::getScore(HighScore &hs) {
+int App::getScore(const HighScore &hs) {
   double ntiles = hs.x*hs.y;
   double tilespersec = ntiles/(double)hs.seconds;
   
@@ -453,15 +474,15 @@ int App::getScore(HighScore &hs) {
     return (int)(points * sizebonus);
 }
 
-bool App::isBetter(HighScore &hs, HighScore &than) {
+bool App::isBetter(const HighScore &hs, const HighScore &than) {
   if(getScore(hs) > getScore(than))
-    return TRUE;
+    return true;
   else
-    return FALSE;
+    return false;
 }
 
 
-int App::insertHighscore(HighScore &hs) {
+int App::insertHighscore(const HighScore &hs) {
   int i;
 
   if(highscore.size() == 0) {
@@ -513,7 +534,6 @@ void App::readHighscore() {
       highscore.resize(i+1);
     
       HighScore hs;
-      memset(hs.name, 0, sizeof(hs.name));
 
       hs.x = hi_x[i].toInt();
       hs.y = hi_y[i].toInt();
@@ -521,8 +541,8 @@ void App::readHighscore() {
       hs.date = hi_date[i].toInt();
       hs.date = hi_date[i].toInt();
       hs.gravity = hi_grav[i].toInt();
-      strncpy(hs.name, hi_name[i].utf8(), 16);
-      
+      hs.name = hi_name[i];
+
       highscore[i] = hs;
   }
 }
@@ -545,7 +565,6 @@ void App::readOldHighscore() {
       highscore.resize(i+1);
 
       HighScore hs;
-      memset(hs.name, 0, sizeof(hs.name));
       
       QStringList e = conf->readListEntry(s, ' ');
       int nelem = e.count();
@@ -557,12 +576,12 @@ void App::readOldHighscore() {
       if (nelem == 4) // old version <= 1.1
       {
         hs.gravity = 0;
-        strncpy(hs.name, (*e.at(4)).utf8(), 16);
+        hs.name = *e.at(4);
       }
       else
       {
         hs.gravity = (*e.at(4)).toInt();
-        strncpy(hs.name, (*e.at(5)).utf8(), 16);
+        hs.name = *e.at(5);
       }
 
       highscore[i] = hs;
@@ -577,7 +596,7 @@ void App::readOldHighscore() {
 //     hs.x = 28;
 //     hs.y = 16;
 //     hs.seconds = 367;
-//     strcpy(hs.name, "Mario");
+//     hs.name = "Mario";
 //     highscore.resize(1);
 //     highscore[0] = hs;
 //   }
@@ -624,7 +643,7 @@ void App::showHighscore(int focusitem)  {
 
   QVBoxLayout *tl = new QVBoxLayout(dlg, 10);
   
-  QLabel *l = new QLabel(i18n("Hall Of Fame"), dlg);
+  QLabel *l = new QLabel(i18n("Hall of Fame"), dlg);
   QFont f = font();
   f.setPointSize(24);
   f.setBold(TRUE);
@@ -719,9 +738,9 @@ void App::showHighscore(int focusitem)  {
     for(j = 0; j < 5; j++) {
       e[i][j]->setMinimumHeight(e[i][j]->sizeHint().height());
       if(j == 1)
-	e[i][j]->setMinimumWidth(MAX(e[i][j]->sizeHint().width(), 100));
+	e[i][j]->setMinimumWidth(std::max(e[i][j]->sizeHint().width(), 100));
       else
-	e[i][j]->setMinimumWidth(MAX(e[i][j]->sizeHint().width(), 60));
+	e[i][j]->setMinimumWidth(std::max(e[i][j]->sizeHint().width(), 60));
       if((int)i == focusitem)
 	e[i][j]->setFont(f);
       table->addWidget(e[i][j], i+2, j, AlignCenter);	
@@ -752,4 +771,9 @@ void App::showHighscore(int focusitem)  {
   delete dlg;
 }
 
+void App::keyBindings()
+{
+  KKeyDialog::configure(actionCollection(), this);
+}
+
 #include "app.moc"
