@@ -75,6 +75,7 @@ Board::Board(QWidget *parent) : QWidget(parent) {
   grav_col_1 = -1;
   grav_col_2 = -1;
   setGravityFlag(false);
+  current_scale = 0.0;
 
   // randomze
   setShuffle(DEFAULTSHUFFLE);
@@ -89,7 +90,7 @@ Board::Board(QWidget *parent) : QWidget(parent) {
   _redo.setAutoDelete(true);
   _undo.setAutoDelete(true);
 
-  loadTiles(1);
+  loadTiles();
   field = 0;
   QPixmap bg(KGlobal::dirs()->findResource("appdata", "kshisen_bgnd.xpm"));
   setBackgroundPixmap(bg);
@@ -99,7 +100,6 @@ Board::Board(QWidget *parent) : QWidget(parent) {
 	  this, SLOT(slotMadeMove(int, int, int, int)));  
 
   setShuffle(0);
-  setSize(18, 8);
 
   highlighted_tile = -1;
 }
@@ -178,36 +178,48 @@ void Board::mousePressEvent(QMouseEvent *e) {
       if(highlighted_tile != -1) {
 	int oldmarkx = mark_x;
 	int oldmarky = mark_y;
-	
 	mark_x=-1; mark_y=-1;
+
+	int old_highlighted = highlighted_tile;
+	highlighted_tile = -1;
+
 	for(int i = 0; i < x_tiles(); i++)
-	  for(int j = 0; j < y_tiles(); j++){
-	    if( highlighted_tile == getField(i, j))
-	      updateField(i, j);	      
-	  }
+	  for(int j = 0; j < y_tiles(); j++)
+	    if(old_highlighted == getField(i, j) && !(i == pos_x && j == pos_y))
+	      updateField(i, j, false);
+
 	mark_x = oldmarkx; 
 	mark_y = oldmarky;   // no tile selected
-	highlighted_tile = -1;
       }
-      
+
       if(pos_x >= 0 && pos_x < x_tiles() && pos_y >= 0 && pos_y < y_tiles())
 	emit fieldClicked(pos_x, pos_y);  
     }
 
     // Assist by lighting all tiles of same type
     if(e->button() == RightButton) {
+      int old_highlighted = highlighted_tile;
       int field = getField(pos_x,pos_y);
       highlighted_tile = field;
-      
+
+      if(mark_x != -1 && getField(mark_x, mark_y) != highlighted_tile){
+        int oldmarkx = mark_x;
+        int oldmarky = mark_y;
+        mark_x=-1; mark_y=-1;
+        updateField(oldmarkx, oldmarky, false);
+      }
+
       for(int i = 0; i < x_tiles(); i++)
 	for(int j = 0; j < y_tiles(); j++){
-	  if( field == getField(i, j)){
+	  int field_tile = getField(i, j);
+	  if(field == field_tile ){
 	    mark_x=i; mark_y=j;
+	    updateField(i, j, false);
 	  }
-	  else{
+	  else if(old_highlighted == field_tile){
 	    mark_x=-1; mark_y=-1;
+	    updateField(i, j, false);
 	  }
-	  updateField(i, j);
 	}
       mark_x=-1; mark_y=-1;   // no tile selected
     }
@@ -227,58 +239,63 @@ void Board::setSize(int x, int y) {
     for(int j = 0; j < y; j++)
       setField(i, j, EMPTY);
 
-  loadTiles();
-  double scaler = 1.0;
-  while(sizeHint().width() > kapp->desktop()->width() - 2*XBORDER ||
-     sizeHint().height() > kapp->desktop()->height() - 2*YBORDER) {
-    scaler -= 0.2;
-    loadTiles(scaler);
-  }
+  // calculate scaling required to fit all tiles on the screen
+  double scale_x = static_cast<double>(kapp->desktop()->width() - 4*XBORDER) /
+    static_cast<double>(unscaled_tile.width() * x_tiles());
+  double scale_y = static_cast<double>(kapp->desktop()->height() - 4*YBORDER) /
+    static_cast<double>(unscaled_tile.height() * y_tiles());
+
+  // round down to nearest multiple of 0.2
+  scale_x = static_cast<int>(scale_x * 5.0) / 5.0;
+  scale_y = static_cast<int>(scale_y * 5.0) / 5.0;
+
+  double scaler = std::min(scale_x, scale_y);
+  scaler = std::min(1.0, scaler); // prevents scaling up
+  loadTiles(scaler);
 
   newGame();
   emit changed();
   emit sizeChange();
 }
 
-bool Board::loadTiles(float scale) {
-  int i, j, x, y;
+bool Board::loadTiles(double scale) {
+  
+  if(scale != current_scale)
+  {
+    int i, j;
 
-  // delete old tiles
-  for(i = 0; i < 45; i++)
-    if(pm_tile[i] != 0) {
-      delete pm_tile[i];
-      pm_tile[i] = 0;
+    // delete old tiles
+    for(i = 0; i < 45; i++) {
+      if(pm_tile[i] != 0) {
+        delete pm_tile[i];
+        pm_tile[i] = 0;
+      }
     }
 
-  // locate tileset
-  QPixmap pm(KGlobal::dirs()->findResource("appdata", "kshisen.xpm"));
-  QBitmap mask(KGlobal::dirs()->findResource("appdata", "mask.xpm"));
-  if(pm.width() == 0 || pm.height() == 0) {
-      KMessageBox::sorry(this,
-                           i18n("Cannot load pixmaps!"));
-      exit(1);
+    // locate tileset
+    QImage tileset(KGlobal::dirs()->findResource("appdata", "kshisen.xpm"));
+    if(tileset.width() == 0 || tileset.height() == 0) {
+        KMessageBox::sorry(this, i18n("Cannot load pixmaps!"));
+        exit(1);
+    }
+
+    int w = tileset.width() / 9;
+    int h = tileset.height() / 5;
+    QSize scaledTileSize( int(scale * w), int(scale * h) );
+
+    for(i = 0; i < 9; i++) {
+      for(j = 0; j < 5; j++) {
+        QImage tile = tileset.copy( w*i, h*j, w, h );
+        if(scale != 1.0)
+          tile = tile.smoothScale(scaledTileSize);
+        pm_tile[i + j*9] = new QPixmap(tile);
+      }
+    }
+
+    unscaled_tile = QSize(w, h);
+    current_scale = scale;
   }
-  pm.setMask(mask);
-  
-  if(pm.width() == 0 || pm.height() == 0)
-    return false;
 
-  x = pm.width() / 9;
-  y = pm.height() / 5;
-  for(i = 0; i < 9; i++)
-    for(j = 0; j < 5; j++) {
-	pm_tile[i + j*9] = new QPixmap(x,y);
-	QBitmap bm(x, y);
-	bitBlt(pm_tile[i + j*9], 0, 0, &pm, x * i, y * j, x, y, CopyROP);
-	bitBlt(&bm, 0, 0, &mask, x *i, y * j, x, y, CopyROP);
-	pm_tile[i+j*9]->setMask(bm);
-	if(scale != 1.0) {
-	  QWMatrix wm;
-	  wm.scale(scale, scale);
-	  *pm_tile[i + j*9] = pm_tile[i + j*9]->xForm(wm);
-	}
-    }
-  
   return true;
 }
 
@@ -301,29 +318,27 @@ void Board::newGame() {
 
   // distribute all tiles on board
   int cur_tile = 0;
-  for(i = 0; i < x_tiles() * y_tiles() * 12; i++) {
-    // map the tileindex to a tile
-    // not all tiles from the pixmap are really used, only
-    // 36 out of 45 are used. This maps and index to
-    // the "real" index.
-    int tile;
-    if(cur_tile == 28)
-      tile = 30;
-    else if(cur_tile >= 29 && cur_tile <= 35)
-      tile = cur_tile + 7;
-    else
-      tile = cur_tile;
-    
-    cur_tile++;
-    if(cur_tile == 36)
-      cur_tile = 0;
+  for(y = 0; y < y_tiles(); y += 4) {
+    for(x = 0; x < x_tiles(); ++x) {
+      // map the tileindex to a tile
+      // not all tiles from the pixmap are really used, only
+      // 36 out of 45 are used. This maps and index to
+      // the "real" index.
+      int tile;
+      if(cur_tile == 28)
+        tile = 31;
+      else if(cur_tile >= 29 && cur_tile <= 35)
+        tile = cur_tile + 8;
+      else
+        tile = cur_tile + 1;
 
-    x = i % x_tiles();
-    y = i / x_tiles() * 4;
+      cur_tile++;
+      if(cur_tile == 36)
+        cur_tile = 0;
 
-    tile++;
-    for(k = 0; k < 4 && k + y < y_tiles(); k++)
-      setField(x, y+k, tile);
+      for(k = 0; k < 4 && k + y < y_tiles(); k++)
+        setField(x, y+k, tile);
+    }
   }
 
   if(getShuffle() == 0) {
@@ -358,7 +373,7 @@ void Board::newGame() {
     return;
   }
 
-  
+
   int fsize = x_tiles() * y_tiles() * sizeof(int);
   int *oldfield = new int[x_tiles() * y_tiles()];
   memcpy(oldfield, field, fsize);			// save field
@@ -413,7 +428,7 @@ void Board::newGame() {
   }
 }
 
-void Board::updateField(int x, int y) {
+void Board::updateField(int x, int y, bool erase) {
   if(trying)
     return;
 
@@ -422,21 +437,7 @@ void Board::updateField(int x, int y) {
 	  pm_tile[0]->width(),
 	  pm_tile[0]->height());
   if(isUpdatesEnabled())
-    repaint(r, true);
-}
-
-int MIN(int a, int b) {
-  if(a < b)
-    return a;
-  else
-    return b;
-}
-
-int MAX(int a, int b) {
-  if(a > b)
-    return a;
-  else
-    return b;
+    repaint(r, erase);
 }
 
 QPixmap *Board::lighten(QPixmap *src) {
@@ -447,7 +448,7 @@ QPixmap *Board::lighten(QPixmap *src) {
     for(int y = 0; y < src->height(); y++) {
       uchar *p = (uchar *)img.scanLine(y);
       for(int x = 0; x < src->width() * 4; x++) {
-	*p = (unsigned char)MIN(255, (int)(FACTOR * (*p)));
+	*p = (unsigned char)std::min(255, (int)(FACTOR * (*p)));
 	p++;
       }
     }
@@ -476,7 +477,8 @@ void Board::paintEvent(QPaintEvent *e) {
   } else {
     for(int i = 0; i < x_tiles(); i++)
       for(int j = 0; j < y_tiles(); j++) {
-	if(getField(i, j) == EMPTY)
+	int tile = getField(i, j);
+	if(tile == EMPTY)
 	  continue;
 
 	int xpos = XBORDER + i * pm_tile[1]->width();
@@ -484,12 +486,12 @@ void Board::paintEvent(QPaintEvent *e) {
 	QRect r(xpos, ypos, pm_tile[1]->width(), pm_tile[1]->height());
 	if(e->rect().intersects(r)) {
 	  // check if it is a marked piece
-	  if(i == mark_x && j == mark_y) {
-	    QPixmap *lpm = lighten(pm_tile[getField(i, j)-1]);
+	  if(tile == highlighted_tile || (i == mark_x && j == mark_y)){
+	    QPixmap *lpm = lighten(pm_tile[tile-1]);
 	    p.drawPixmap(xpos, ypos, *lpm);
 	    delete lpm;
 	  } else
-	    p.drawPixmap(xpos, ypos, *pm_tile[getField(i, j)-1]);
+	    p.drawPixmap(xpos, ypos, *pm_tile[tile-1]);
 	}
       }
   }
@@ -507,14 +509,14 @@ void Board::marked(int x, int y) {
     // unmark the piece
     mark_x = -1;
     mark_y = -1;
-    updateField(x, y);
+    updateField(x, y, false);
     return;
   }
 
   if(mark_x == -1) {
     mark_x = x;
     mark_y = y;
-    updateField(x, y);
+    updateField(x, y, false);
     return;
   } else {
     int fld1 = getField(mark_x, mark_y);
@@ -551,7 +553,7 @@ bool Board::canMakePath(int x1, int y1, int x2, int y2) {
   int i;
 
   if(x1 == x2) {
-    for(i = MIN(y1, y2)+1; i < MAX(y1, y2); i++) 
+    for(i = std::min(y1, y2)+1; i < std::max(y1, y2); i++)
       if(getField(x1, i) != EMPTY)
 	return false;
   
@@ -559,7 +561,7 @@ bool Board::canMakePath(int x1, int y1, int x2, int y2) {
   } 
 
   if(y1 == y2) {
-    for(i = MIN(x1, x2)+1; i < MAX(x1, x2); i++)
+    for(i = std::min(x1, x2)+1; i < std::max(x1, x2); i++)
       if(getField(i, y1) != EMPTY)
 	return false;
 
@@ -699,12 +701,12 @@ void Board::undrawArrow() {
   int num = 0;
   while(num < 3 && history[num+1].x != -2) {
     if(history[num].y == history[num+1].y)
-      for(int i = MIN(history[num].x, history[num+1].x); 
-	  i <= MAX(history[num].x, history[num+1].x); i++)
+      for(int i = std::min(history[num].x, history[num+1].x); 
+	  i <= std::max(history[num].x, history[num+1].x); i++)
 	updateField(i, history[num].y);
     else 
-      for(int i = MIN(history[num].y, history[num+1].y); 
-	  i <= MAX(history[num].y, history[num+1].y); i++)
+      for(int i = std::min(history[num].y, history[num+1].y); 
+	  i <= std::max(history[num].y, history[num+1].y); i++)
 	updateField(history[num].x, i);
     num++;
   }
@@ -939,7 +941,7 @@ int Board::tilesLeft() {
   int left = 0;
 
   for(int i = 0; i < x_tiles(); i++)
-    for(int j = 0; j < x_tiles(); j++)
+    for(int j = 0; j < y_tiles(); j++)
       if(getField(i, j) != EMPTY)
 	left++;
 
