@@ -5,7 +5,7 @@
 
 #include <qpixmap.h>
 #include <qwidget.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 #include <krandomsequence.h>
 
@@ -44,7 +44,7 @@ signals:
 private:
     Board   *board;
     PixServer *pixServer;
-    QList<Kaffee> *list;
+    QPtrList<Kaffee> *list;
     KRandomSequence random;
 };
 
