@@ -2,6 +2,7 @@
 #define PIXSERVER_H
 
 #include <qpixmap.h>
+#include <qimage.h>
 #include <qcolor.h>
 
 #include "board.h"
@@ -20,7 +21,7 @@ class PixServer
 {
 public:
     PixServer (Board *, QWidget *parent=0);
-    QPixmap levelPix() { return roomPix; }
+    QPixmap levelPix() { return cachePix; }
 
     void initRoomPixmap();
     void initBrickPixmap();
@@ -33,7 +34,6 @@ public:
 private:
     QWidget *w;
     Board *board;
-    QString pixDir;
 
     void drawBrick(QPainter *, int);
 
@@ -42,7 +42,8 @@ private:
     QPixmap ballPix[4];
     QPixmap applePix[2];
 
-    QPixmap roomPix;
+    QPixmap roomPix; 
+    QPixmap cachePix;
     QPixmap offPix;
     QPixmap backPix;
 
