@@ -4,12 +4,13 @@
 #include <qpoint.h>
 #include <math.h>
 #include <qcolor.h>
+#include <qbitmap.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaccel.h>
 #include <kaction.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kglobal.h>
 #include <kconfig.h>
 #include <qfile.h>
@@ -81,9 +82,9 @@ MyMainView::MyMainView(QWidget *parent, const char *name)
    {
       // ship[i]->setBoundsAction(QwRealMobileSprite::Wrap);
       ship[i]->hide();
-      bullets[i]=new QList<BulletSprite>;
+      bullets[i]=new QPtrList<BulletSprite>;
       bullets[i]->setAutoDelete(true);
-      mines[i]=new QList<MineSprite>;
+      mines[i]=new QPtrList<MineSprite>;
       mines[i]->setAutoDelete(true);
 
    }
@@ -247,17 +248,17 @@ void MyMainView::writeConfig()
    cfg->writeEntry("startHitPoints",options.startHitPoints[0]);
 
    cfg->setGroup("Player2");
-   cfg->writeEntry("KeyLeft",KAccel::keyToString(options.playerKey[1][PlayerKeyLeft]));
-   cfg->writeEntry("KeyRight",KAccel::keyToString(options.playerKey[1][PlayerKeyRight]));
-   cfg->writeEntry("KeyAcc",KAccel::keyToString(options.playerKey[1][PlayerKeyAcc]));
-   cfg->writeEntry("KeyShot",KAccel::keyToString(options.playerKey[1][PlayerKeyShot]));
-   cfg->writeEntry("KeyMine",KAccel::keyToString(options.playerKey[1][PlayerKeyMine]));
+   cfg->writeEntry("KeyLeft",KKey(options.playerKey[1][PlayerKeyLeft]).toStringInternal());
+   cfg->writeEntry("KeyRight",KKey(options.playerKey[1][PlayerKeyRight]).toStringInternal());
+   cfg->writeEntry("KeyAcc",KKey(options.playerKey[1][PlayerKeyAcc]).toStringInternal());
+   cfg->writeEntry("KeyShot",KKey(options.playerKey[1][PlayerKeyShot]).toStringInternal());
+   cfg->writeEntry("KeyMine",KKey(options.playerKey[1][PlayerKeyMine]).toStringInternal());
    cfg->setGroup("Player1");
-   cfg->writeEntry("KeyLeft",KAccel::keyToString(options.playerKey[0][PlayerKeyLeft]));
-   cfg->writeEntry("KeyRight",KAccel::keyToString(options.playerKey[0][PlayerKeyRight]));
-   cfg->writeEntry("KeyAcc",KAccel::keyToString(options.playerKey[0][PlayerKeyAcc]));
-   cfg->writeEntry("KeyShot",KAccel::keyToString(options.playerKey[0][PlayerKeyShot]));
-   cfg->writeEntry("KeyMine",KAccel::keyToString(options.playerKey[0][PlayerKeyMine]));
+   cfg->writeEntry("KeyLeft",KKey(options.playerKey[0][PlayerKeyLeft]).toStringInternal());
+   cfg->writeEntry("KeyRight",KKey(options.playerKey[0][PlayerKeyRight]).toStringInternal());
+   cfg->writeEntry("KeyAcc",KKey(options.playerKey[0][PlayerKeyAcc]).toStringInternal());
+   cfg->writeEntry("KeyShot",KKey(options.playerKey[0][PlayerKeyShot]).toStringInternal());
+   cfg->writeEntry("KeyMine",KKey(options.playerKey[0][PlayerKeyMine]).toStringInternal());
    cfg->setGroup("Game");
 
    cfg->writeEntry("player1IsAi",options.isAi[0]);
@@ -323,7 +324,7 @@ void MyMainView::keyPressEvent(QKeyEvent *ev)
       if(!accept)
          ev->ignore();
    }
-   
+
 }
 
 void MyMainView::keyReleaseEvent(QKeyEvent *ev)
@@ -350,7 +351,7 @@ void MyMainView::pause()
          ( (KMainWindow* )parent( )->parent( ) )
          ->actionCollection( )->action( "pause" );
       pauseAction->setChecked( true );
-      
+
       waitForStart=true;
       killTimers();
       emit setStatusText(i18n(" paused "), IDS_PAUSE);
@@ -394,7 +395,7 @@ void MyMainView::stop()
       ->actionCollection( )->action( "pause" );
    pauseAction->setEnabled( false );
    pauseAction->setChecked( false );
-   
+
    killTimers();
    waitForStart = true;
 }
@@ -470,7 +471,7 @@ void MyMainView::newRound()
    ship[0]->move(mx+config.startPosX,my+config.startPosY);
    ship[0]->setRotation(0.0);
    ship[0]->setFrame(0);
-   
+
    ship[1]->move(mx-config.startPosX,my-config.startPosY);
    ship[1]->setRotation(M_PI);
    ship[1]->setFrame(ROTNUM/2);
@@ -510,11 +511,11 @@ void MyMainView::newRound()
       textSprite=0;
    }
    field.update();
-   
+
    QString str = i18n("Press %1 to start")
-      .arg( KAccel::keyToString( ( (KMainWindow*)(parent()->parent()) )
+      .arg( ( (KMainWindow*)(parent()->parent()) )
                                 ->actionCollection()->action("game_start")
-                                ->accel(), true) );
+                                ->shortcut().toString() );
    emit(setStatusText(str,IDS_MAIN));
    emit( setStatusText( "", IDS_PAUSE ) );
    stop( );
@@ -535,6 +536,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
 {
    unsigned w;
    int i;
+   bool stopped = false;
 
    if(event->timerId()==timerID)
    {
@@ -544,6 +546,14 @@ void MyMainView::timerEvent(QTimerEvent *event)
          gameEnd-=1.0;
          if(gameEnd<=0.0)
          {
+            stopped = true;
+            if(textSprite)
+            {
+               textSprite->hide();
+               delete textSprite;
+               textSprite=0;
+            }
+
             textSprite=new QCanvasText(&field);
             textSprite->move(width()/2,height()/2-90);
             textSprite->setTextFlags(AlignCenter);
@@ -570,28 +580,28 @@ void MyMainView::timerEvent(QTimerEvent *event)
                emit(wins(0,w));
             }
             QString str = i18n("Press %1 for new round")
-               .arg(KAccel::keyToString( ( ( KMainWindow* )( parent( )->parent( ) ) )
+               .arg(( ( KMainWindow* )( parent( )->parent( ) ) )
                                          ->actionCollection( )->action( "game_start" )
-                                         ->accel( ), true) );
+                                         ->shortcut( ).toString() );
             emit(setStatusText(str,IDS_MAIN));
             stop( );
          }
-         else
-            timerID=startTimer(options.refreshTime);      
       }
-      else
-         timerID=startTimer(options.refreshTime);
 
-      for(i=0;i<2;i++)
-         if(options.isAi[i]&&(ship[i]->getHitPoints()>0))
-            ai[i]->think();
-      
-      moveMines();
-      moveBullets();
-      moveExplosions();
-      moveShips();
-      calculatePowerups();
-      collisions();
+      if( !stopped )
+      {
+         for(i=0;i<2;i++)
+            if(options.isAi[i]&&(ship[i]->getHitPoints()>0))
+               ai[i]->think();
+
+         moveMines();
+         moveBullets();
+         moveExplosions();
+         moveShips();
+         calculatePowerups();
+         collisions();
+         timerID=startTimer(options.refreshTime);
+      }
       field.update();
    }
 }
@@ -618,7 +628,7 @@ void MyMainView::moveShips()
          ship[i]->calculateGravityAndEnergy(config.gravity,config.sunEnergy,
                                          config.gamespeed);
 
-         
+
          if(!options.isAi[i]&&playerKeyPressed[i][PlayerKeyRight]
             || options.isAi[i]&&ai[i]->rotateRight())
             ship[i]->rotateRight(config.rotationEnergyNeed,
@@ -628,11 +638,11 @@ void MyMainView::moveShips()
             || options.isAi[i]&&ai[i]->rotateLeft())
             ship[i]->rotateLeft(config.rotationEnergyNeed,
                                 config.rotationSpeed);
- 
+
          en=ship[i]->getEnergy();
          nr=ship[i]->getRotation();
 
-         
+
          nf=ship[i]->frame();
          nx=cos(nr);
          ny=sin(nr);
@@ -667,7 +677,7 @@ void MyMainView::moveShips()
                                       ship[i]->yVelocity()-ny*config.shotSpeed);
                   // bullet->setBoundsAction(QwRealMobileSprite::Wrap);
                   bullet->show();
-                  
+
                   bullets[i]->append(bullet);
                }
             }
@@ -935,7 +945,7 @@ void MyMainView::collisions()
          }
       }
    }
-   
+
    hitlist.clear();
    unexact.clear();
    unexact=sun->collisions(false);
@@ -1014,7 +1024,7 @@ void MyMainView::keySetup()
    KeySetup dialog(&options,this);
    dialog.exec();
 //   QString str = i18n("Press %1 to start/resume")
-//           .arg(KAccel::keyToString(options.functionKey[FunctionKeyStart]));
+//           .arg(KKey::keyToString(options.functionKey[FunctionKeyStart]));
 //   emit(setStatusText(str,IDS_MAIN));
 }
 
@@ -1046,8 +1056,8 @@ QCanvasPixmapArray* MyMainView::loadOldPixmapSequence(const QString& datapattern
                             const QString& maskpattern, int framecount)
 {
    int image;
-   QList<QPixmap> pixmaplist;
-   QList<QPoint> pointlist;
+   QPtrList<QPixmap> pixmaplist;
+   QPtrList<QPoint> pointlist;
    QString dataname, maskname;
    QPixmap *pix;
    QBitmap *bitmap;
