@@ -29,13 +29,11 @@
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <qtimer.h>
-#include <qstring.h>
 #include <math.h>
 #include <krandomsequence.h>
 
-class KAccel;
 class KConfig;
+class KActionCollection;
 
 #include "player.h"
 
@@ -56,7 +54,7 @@ class Tron : public QWidget
 public:
   Tron(QWidget *parent=0, const char *name=0);
   ~Tron();
-  void setAccel(KAccel *);
+  void setActionCollection(KActionCollection*);
   void updatePixmap();
   void setBackgroundPix(QPixmap);
   bool changeColor(int player);
@@ -109,7 +107,7 @@ protected:
 
 private:
   /** Stores key shortcuts */
-  KAccel* accel;
+  KActionCollection* actionCollection;
   /** Drawing buffer */
   QPixmap *pixmap;
   /** The playingfield */
