@@ -16,7 +16,6 @@
  ***************************************************************************/
 
 // include files for QT
-#include <qdir.h>
 #include <qstring.h>
 #include <qlayout.h>
 #include <qhgroupbox.h>
@@ -29,16 +28,15 @@
 
 // include files for KDE
 #include <kstandarddirs.h>
-#include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
-#include <kmenubar.h>
 #include <klocale.h>
 #include <khelpmenu.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kstdaction.h>
 #include <kaction.h>
+#include <kkeydialog.h>
 
 #include <kchatdialog.h>
 #include <kgamechat.h>
@@ -392,9 +390,9 @@ void Kwin4App::initGUI()
                         actionCollection(), "file_debug");
   }
 
-  (void)new KAction(i18n("&Show Statistics..."),"flag", 0, this, SLOT(slotFileStatistics()),
+  (void)new KAction(i18n("&Show Statistics"),"flag", 0, this, SLOT(slotFileStatistics()),
                       actionCollection(), "statistics");
-  ACTION("statistics")->setStatusText(i18n("Show all time statistics..."));
+  ACTION("statistics")->setStatusText(i18n("Show all time statistics."));
   ACTION("statistics")->setWhatsThis(i18n("Shows the all time statistics which is kept in all sessions."));
 
   (void)new KAction(i18n("&Hint"),"help", CTRL+Key_H, this, SLOT(slotFileHint()),
@@ -419,9 +417,9 @@ void Kwin4App::initGUI()
   ACTION("show_statusbar")->setStatusText(i18n("Toggle the statusbar..."));
   ACTION("show_statusbar")->setWhatsThis(i18n("Toggle the statusbar..."));
 
-  (void)new KSelectAction(i18n("Startplayer"),0,this,SLOT(slotStartplayer()),
+  (void)new KSelectAction(i18n("Starting Player"),0,this,SLOT(slotStartplayer()),
                       actionCollection(), "startplayer");
-  ACTION("startplayer")->setStatusText(i18n("Changing startplayer..."));
+  ACTION("startplayer")->setStatusText(i18n("Changing starting player..."));
   ACTION("startplayer")->setWhatsThis(i18n("Chooses which player begins the next game."));
   list.clear();
   list.append(i18n("&Yellow"));
@@ -470,6 +468,8 @@ void Kwin4App::initGUI()
   connect(actionCollection(), SIGNAL(actionStatusText(const QString &)), SLOT(slotStatusMsg(const QString &)));
   connect(actionCollection(), SIGNAL(clearStatusText()), SLOT(slotClearStatusMsg()));
 
+  KStdAction::keyBindings(this, SLOT(slotKeyBindings()), actionCollection());
+
   KHelpMenu *helpMenu = new KHelpMenu(this, 0, true, actionCollection());
   connect( helpMenu, SIGNAL(showAboutApplication()), this, SLOT(slotHelpAbout()));
 
@@ -788,7 +788,7 @@ void Kwin4App::slotFileStatistics()
 {
   int res;
 
-  StatDlg *dlg=new StatDlg(this,"Game statistics...");
+  StatDlg *dlg=new StatDlg(this,"Game statistics");
   dlg->SetNames(doc->QueryName(Gelb),doc->QueryName(Rot));
   dlg->SetStat1(doc->QueryStat(Gelb,TWin),
                 doc->QueryStat(Gelb,TRemis),
@@ -1162,7 +1162,7 @@ void Kwin4App::slotGameOver(int status, KPlayer * p, KGame * /*me*/)
     EndGame(TRemis);
     checkMenus(CheckEditMenu);
     slotStatusMsg(i18n("The game is drawn. Please restart next round."));
-    //KMessageBox::information(this,i18n("The game ended remis!\n"),appTitle());
+    //KMessageBox::information(this,i18n("The game ended inadvertently!\n"),appTitle());
   }
   else if (status==1)
   {
@@ -1305,7 +1305,10 @@ void Kwin4App::slotDebugKGame()
  d->show();
 }
 
-
+void Kwin4App::slotKeyBindings()
+{
+ KKeyDialog::configure(actionCollection(), this);
+}
 
 
 #include "kwin4.moc"
