@@ -21,11 +21,9 @@
 // include files for Qt
 #include <qdir.h>
 #include <qfileinfo.h>
-#include <qwidget.h>
 
 // include files for KDE
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
@@ -413,7 +411,7 @@ MOVESTATUS Kwin4Doc::MakeMove(int x,int mode){
 
   pView->setArrow(x,mLastColour);
   // animation onyl if no redo
-  pView->setPiece(x,y,mLastColour,mCurrentMove,mode==1?false:true);
+  pView->setPiece(x,y,mLastColour,mCurrentMove-1,mode==1?false:true);
   pView->setHint(0,0,false);
  
   return GNormal;
