@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kcarddialog.cpp,v 1.21 2002/02/20 15:13:58 coolo Exp $
+    $Id: kcarddialog.cpp,v 1.23.2.1 2003/01/03 04:54:52 mueller Exp $
 */
 
 #include <stdio.h>
@@ -306,12 +306,12 @@ void KCardDialog::setupDialog(bool showResizeBox)
     d->randomDeck->setChecked(false);
     connect(d->randomDeck, SIGNAL(toggled(bool)), this,
             SLOT(slotRandomDeckToggled(bool)));
-    d->randomDeck->setText(i18n("Random Backside"));
+    d->randomDeck->setText(i18n("Random backside"));
     l->addWidget(d->randomDeck, 0, AlignTop|AlignHCenter);
 
     d->globalDeck = new QCheckBox(plainPage());
     d->globalDeck->setChecked(false);
-    d->globalDeck->setText(i18n("Use Global Backside"));
+    d->globalDeck->setText(i18n("Use global backside"));
     l->addWidget(d->globalDeck, 0, AlignTop|AlignHCenter);
 
     QPushButton* b = new QPushButton(i18n("Make Backside Global"), plainPage());
@@ -356,12 +356,12 @@ void KCardDialog::setupDialog(bool showResizeBox)
     d->randomCardDir->setChecked(false);
     connect(d->randomCardDir, SIGNAL(toggled(bool)), this,
             SLOT(slotRandomCardDirToggled(bool)));
-    d->randomCardDir->setText(i18n("Random Frontside"));
+    d->randomCardDir->setText(i18n("Random frontside"));
     l->addWidget(d->randomCardDir, 0, AlignTop|AlignHCenter);
 
     d->globalCardDir = new QCheckBox(plainPage());
     d->globalCardDir->setChecked(false);
-    d->globalCardDir->setText(i18n("Use Global Frontside"));
+    d->globalCardDir->setText(i18n("Use global frontside"));
     l->addWidget(d->globalCardDir, 0, AlignTop|AlignHCenter);
 
     QPushButton* b = new QPushButton(i18n("Make Frontside Global"), plainPage());
@@ -798,10 +798,6 @@ void KCardDialog::init()
     if (_inited)
         return;
     KGlobal::dirs()->addResourceType("cards", KStandardDirs::kde_default("data") + QString::fromLatin1("carddecks/"));
-#ifdef SRCDIR
-    KGlobal::dirs()->addResourceDir("cards", SRCDIR + QString::fromLatin1("/carddecks/"));
-#endif
-
     KGlobal::locale()->insertCatalogue("libkdegames");
     _inited = true;
 }
