@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgame.cpp,v 1.76.2.1 2002/05/22 19:45:50 andreas Exp $
+    $Id: kgame.cpp,v 1.81 2002/07/14 20:03:26 heni Exp $
 */
 
 #include "kgamepropertyhandler.h"
@@ -198,60 +198,63 @@ bool KGame::loadgame(QDataStream &stream, bool network,bool resetgame)
 
  stream >> d->mUniquePlayerNumber;
 
-  d->mCurrentPlayer=0;  // TODO !!!
-  int newseed;
-  stream >> newseed;
-  d->mRandom->setSeed(newseed);
+ d->mCurrentPlayer=0;  // TODO !!!
+ int newseed;
+ stream >> newseed;
+ d->mRandom->setSeed(newseed);
 
-  // Switch off the direct emitting of signals while
-  // loading properties. This can cause inconsistencies
-  // otherwise if a property emits and this emit accesses
-  // a property not yet loaded
-  // Note we habe to have this external locking to prevent the games unlocking
-  // to access the players
-  dataHandler()->lockDirectEmit();
-  KPlayer *player;
-  for ( player=playerList()->first(); player != 0; player=playerList()->next() )
-  {
-    player->dataHandler()->lockDirectEmit();
-    // kdDebug(11001) << "Player "<<player->id() << " to indirect emit" <<endl;
-  }
+ // Switch off the direct emitting of signals while
+ // loading properties. This can cause inconsistencies
+ // otherwise if a property emits and this emit accesses
+ // a property not yet loaded
+ // Note we habe to have this external locking to prevent the games unlocking
+ // to access the players
+ dataHandler()->lockDirectEmit();
+ KPlayer *player;
+ for ( player=playerList()->first(); player != 0; player=playerList()->next() )
+ {
+   player->dataHandler()->lockDirectEmit();
+   // kdDebug(11001) << "Player "<<player->id() << " to indirect emit" <<endl;
+ }
 
-  // Properties
-  dataHandler()->load(stream);
+ // Properties
+ dataHandler()->load(stream);
 
+ // If there is additional data to be loaded before players are loaded then do
+ // this here.
+ emit signalLoadPrePlayers(stream);
 
-  // Load Playerobjects
-  uint playercount;
-  stream >> playercount;
-  kdDebug(11001) << "Loading KGame " << playercount << " KPlayer objects " << endl;
-  for (i=0;i<playercount;i++)
-  {
-    KPlayer *newplayer=loadPlayer(stream,network);
-    systemAddPlayer(newplayer);
-  }
+ // Load Playerobjects
+ uint playercount;
+ stream >> playercount;
+ kdDebug(11001) << "Loading KGame " << playercount << " KPlayer objects " << endl;
+ for (i=0;i<playercount;i++)
+ {
+   KPlayer *newplayer=loadPlayer(stream,network);
+   systemAddPlayer(newplayer);
+ }
 
-  Q_INT16 cookie;
-  stream >> cookie;
-  if (cookie==KGAME_LOAD_COOKIE) {
-    kdDebug(11001) << "   Game loaded propertly"<<endl;
-  } else {
-    kdError(11001) << "   Game loading error. probably format error"<<endl;
-  }
+ Q_INT16 cookie;
+ stream >> cookie;
+ if (cookie==KGAME_LOAD_COOKIE) {
+   kdDebug(11001) << "   Game loaded propertly"<<endl;
+ } else {
+   kdError(11001) << "   Game loading error. probably format error"<<endl;
+ }
 
-  // Switch back on the direct emitting of signals and emit the
-  // queued signals.
-  // Note we habe to have this external locking to prevent the games unlocking
-  // to access the players
-  dataHandler()->unlockDirectEmit();
-  for ( player=playerList()->first(); player != 0; player=playerList()->next() )
-  {
-    player->dataHandler()->unlockDirectEmit();
-    // kdDebug(11001) << "Player "<<player->id() << " to direct emit" <<endl;
-  }
+ // Switch back on the direct emitting of signals and emit the
+ // queued signals.
+ // Note we habe to have this external locking to prevent the games unlocking
+ // to access the players
+ dataHandler()->unlockDirectEmit();
+ for ( player=playerList()->first(); player != 0; player=playerList()->next() )
+ {
+   player->dataHandler()->unlockDirectEmit();
+   // kdDebug(11001) << "Player "<<player->id() << " to direct emit" <<endl;
+ }
 
-  emit signalLoad(stream);
-  return true;
+ emit signalLoad(stream);
+ return true;
 }
 
 bool KGame::save(QString filename,bool saveplayers)
@@ -272,6 +275,9 @@ bool KGame::save(QString filename,bool saveplayers)
 }
 
 bool KGame::save(QDataStream &stream,bool saveplayers)
+{ return savegame(stream, false,saveplayers); }
+
+bool KGame::savegame(QDataStream &stream,bool /*network*/,bool saveplayers)
 {
   // Save Game Data
 
@@ -288,6 +294,9 @@ bool KGame::save(QDataStream &stream,bool saveplayers)
 
  // Properties
  dataHandler()->save(stream);
+ 
+ // Save all data that need to be saved *before* the players are saved
+ emit signalSavePrePlayers(stream);
 
  if (saveplayers)
  {
@@ -501,11 +510,7 @@ bool KGame::removePlayer(KPlayer * player, Q_UINT32 receiver)
 
 void KGame::systemRemovePlayer(KPlayer* player,bool deleteit)
 {
- if (player) 
- {
-   emit signalPlayerLeftGame(player);
- }
- else 
+ if (!player) 
  {
    kdWarning(11001) << "cannot remove NULL player" << endl;
    return;
@@ -541,6 +546,8 @@ bool KGame::systemRemove(KPlayer* p,bool deleteit)
    result = d->mPlayerList.remove(p);
  }
 
+ emit signalPlayerLeftGame(p);
+
  p->setGame(0);
  if (deleteit) 
  {
@@ -1164,7 +1171,8 @@ void KGame::setupGameContinue(QDataStream& stream, Q_UINT32 sender)
   // Save the game over the network
   QByteArray bufferS;
   QDataStream streamS(bufferS,IO_WriteOnly);
-  save(streamS);
+  // Save game over netowrk and save players
+  savegame(streamS,true,true);
   sendSystemMessage(streamS,KGameMessage::IdGameLoad,sender);
  
 
@@ -1240,6 +1248,7 @@ void KGame::slotClientConnected(Q_UINT32 clientID)
 
 void KGame::slotServerDisconnected() // Client side
 {
+  kdDebug(11001) << "======= SERVER DISCONNECT ======="<<endl;
   kdDebug(11001) << "+++ (CLIENT)++++++++" << k_funcinfo << ": our GameID="<<gameId() << endl;
 
   int oldgamestatus=gameStatus();
@@ -1247,6 +1256,7 @@ void KGame::slotServerDisconnected() // Client side
   KPlayer *player;
   KGamePlayerList removeList;
   kdDebug(11001) << "Playerlist of client=" << d->mPlayerList.count() << " count" << endl;
+  kdDebug(11001) << "Inactive Playerlist of client=" << d->mInactivePlayerList.count() << " count" << endl;
   for ( player=d->mPlayerList.first(); player != 0; player=d->mPlayerList.next() ) 
   {
     // TODO: CHECK: id=0, could not connect to server in the first place??
