@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgame.h,v 1.50 2002/01/17 20:57:30 heni Exp $
+    $Id: kgame.h,v 1.53 2002/07/14 20:03:26 heni Exp $
 */
 #ifndef __KGAME_H_
 #define __KGAME_H_
@@ -504,7 +504,23 @@ signals:
      * removed completely.
      **/
     void signalReplacePlayerIO(KPlayer* player, bool* remove);
-    
+
+    /**
+     * The game will be loaded from the given stream. Load from here
+     * the data which is NOT a game or player property.
+     * It is not necessary to use this signal for a full property game.
+     *
+     * This signal is emitted <em>before</em> the players are loaded by @ref
+     * KGame. See also @ref signalLoad
+     *
+     * You must load <em>exactly</em> the same data from the stream that you have saved
+     * in @ref signalSavePrePlayers! Otherwise player loading will not work
+     * anymore.
+     *
+     * @param stream the load stream
+     */
+    void signalLoadPrePlayers(QDataStream &stream);
+
     /**
      * The game will be loaded from the given stream. Load from here
      * the data which is NOT a game or player property.
@@ -514,6 +530,21 @@ signals:
      */
     void signalLoad(QDataStream &stream);
 
+    /**
+     * The game will be saved to the given stream. Fill this with data
+     * which is NOT a game or player property.
+     * It is not necessary to use this signal for a full property game.
+     *
+     * This signal is emitted <em>before</em> the players are saved by @ref
+     * KGame. See also @ref signalSave
+     *
+     * If you can choose between signalSavePrePlayers and @ref signalSave then
+     * better use @ref signalSave
+     *
+     * @param stream the save stream
+     **/
+    void signalSavePrePlayers(QDataStream &stream);
+    
     /**
      * The game will be saved to the given stream. Fill this with data
      * which is NOT a game or player property.
@@ -554,6 +585,11 @@ signals:
     /**
      * a player left the game because of a broken connection or so!
      *
+     * Note that when this signal is emitted the player is not part of @ref
+     * playerList anymore but the pointer is still valid. You should do some
+     * final cleanups here since the player is usually deleted after the signal
+     * is emitted.
+     *
      * @param player the player who left the game
      */
     void signalPlayerLeftGame(KPlayer *player);
@@ -763,7 +799,6 @@ protected:
      * Use @ref removePlayer to send @ref KGameMessage::IdRemovePlayer. As soon
      * as this Id is received systemRemovePlayer is called and the player is
      * removed directly.
-     *
      **/
     void systemRemovePlayer(KPlayer* player,bool deleteit);
 
@@ -811,6 +846,17 @@ protected:
      */
     virtual bool loadgame(QDataStream &stream, bool network,bool reset);
 
+    /**
+     * Save a game, to file OR network. Internal. 
+     *
+     * @param stream a data stream where you can stream the game from
+     * @param is it a call from the network or from a file (unused but informative)
+     * @param saveplayers - shall the players be saved too (should be TRUE)
+     *
+     * @return true?
+     */
+    virtual bool savegame(QDataStream &stream, bool network,bool saveplayers);
+
 private:
     //AB: this is to hide the "receiver" parameter from the user. It shouldn't be
     //used if possible (except for init).
